@@ -1,5 +1,5 @@
 #!/bin/sh
-LANGS="de fr"
+LANGS="de fr sv"
 
 echo -n "update pot..."
 xml2pot en/index.docbook > en/handbook.pot
