@@ -22,6 +22,8 @@
 
 #include <qfile.h>
 #include <qtextstream.h>
+#include <kmessagebox.h>
+#include <klocale.h>
 
 CiscoPasswdDecoder::CiscoPasswdDecoder(QString& profileFile)
 {
@@ -51,8 +53,12 @@ void CiscoPasswdDecoder::readProfileData(QString& profile, QString& userData, QS
 					userData=line.section('=',1,1).stripWhiteSpace();
 			}
 		}
+		PcfFile.close();
+	}
+	else
+	{
+		KMessageBox::error ( 0, i18n ( "Reading of \"%1\" has been failed!" ).arg ( PcfFile.name() ) );
 	}
-	PcfFile.close();
 }
 
 int CiscoPasswdDecoder::hex2bin_c(unsigned int c)
@@ -158,7 +164,7 @@ bool CiscoPasswdDecoder::decodePasswords(QString& userPasswd, QString& groupPass
 
 	if (!encGroupPasswd.isEmpty())
 	{
-		ret = hex2bin( encGroupPasswd.ascii(), bin, len);
+		ret = hex2bin( encGroupPasswd, bin, len);
 
 
 		if (ret != 0)
@@ -176,9 +182,10 @@ bool CiscoPasswdDecoder::decodePasswords(QString& userPasswd, QString& groupPass
 		else
 		{
 // 		printf("groupPasswd: %s\n", pw);
-// 			std::cout << "groupPasswd: " << pw << std::endl;
+// 			std::cout << "groupPasswd: " << QString::fromLocal8Bit(pw) << std::endl;
+			
 
-		groupPasswd = QString(pw);
+		groupPasswd = QString::fromLocal8Bit(pw);
 		//free(pw);
 		}
 	}
@@ -187,7 +194,7 @@ bool CiscoPasswdDecoder::decodePasswords(QString& userPasswd, QString& groupPass
 		i=0;
 		len2=0;
 	 	ret = 0;
-		ret = hex2bin( encUserPasswd.ascii(), bin2, len2);
+		ret = hex2bin( encUserPasswd, bin2, len2);
 
 		if (ret != 0)
 		{
@@ -204,13 +211,17 @@ bool CiscoPasswdDecoder::decodePasswords(QString& userPasswd, QString& groupPass
 		else
 		{
 
-// 		printf("userPasswd: %s\n", pw2);
-		userPasswd =  pw2;
+// // 		printf("userPasswd: %s\n", pw2);
+// 		std::cout << "userPasswd " << QString::fromLocal8Bit(pw2) << std::endl;
+		userPasswd = QString::fromLocal8Bit(pw2);
+
 
 		//free(pw);
 		}
 	}
 
+	
+
 	return success;
 
 }
