@@ -60,7 +60,6 @@ void ConfigDaemonOptions::programsInPathToggled( bool )
 		VpncPathInput->setEnabled( false );
 		FreeswanPathInput->setEnabled( false );
 		//spinRacoonDebugLevel->setEnabled( false );
-		SetkeyPathInput->setEnabled( false );
 		RacoonPathInput->setEnabled( false );
 		OpenvpnPathInput->setEnabled( false );
 // 		ConfigHelperProgramOptionsWidget->OpenSSLPathInput->setEnabled( false );
@@ -73,7 +72,6 @@ void ConfigDaemonOptions::programsInPathToggled( bool )
 		VpncPathInput->setEnabled( true );
 		FreeswanPathInput->setEnabled( true );
 		//spinRacoonDebugLevel->setEnabled( true );
-		SetkeyPathInput->setEnabled( true );
 		RacoonPathInput->setEnabled( true );
 		OpenvpnPathInput->setEnabled( true );
 // 		ConfigHelperProgramOptionsWidget->OpenSSLPathInput->setEnabled( true );
