@@ -78,3 +78,11 @@ void ConfigLogOptions::useColorizedLogOutputToggled(bool)
 		ColorGroupBox->setEnabled(false);
 }
 
+void ConfigLogOptions::backgroundLogColorClicked()
+{
+	int result = KColorDialog::getColor( BackgroundLogColor );
+	if ( result == KColorDialog::Accepted )
+		BackgroundLogLabel->setPaletteBackgroundColor (BackgroundLogColor);
+}
+
+
