@@ -20,12 +20,13 @@
 #include "debugoutputtextedit.h"
 
 #include <klocale.h>
+#include <ktextbrowser.h>
 #include <iostream>
 #include <qwidget.h>
 #include "debugoutputtextedit.moc"
 
 DebugOutputTextEdit::DebugOutputTextEdit( QWidget* parent, const char* name)
-    : QTextEdit( parent, name)
+    : KTextBrowser( parent, name)
 {
 
 
@@ -33,7 +34,8 @@ DebugOutputTextEdit::DebugOutputTextEdit( QWidget* parent, const char* name)
 
 DebugOutputTextEdit::~DebugOutputTextEdit()
 {
-// 	delete popup;
+	if (popup != 0)
+		delete popup;
 }
 
 QPopupMenu* DebugOutputTextEdit::createPopupMenu(const QPoint &)
@@ -50,5 +52,5 @@ QPopupMenu* DebugOutputTextEdit::createPopupMenu(const QPoint &)
 
 void DebugOutputTextEdit::append ( const QString & text )
 {
-	QTextEdit::append(text);
+	KTextBrowser::append(text);
 }
