@@ -20,7 +20,7 @@
 #ifndef DEBUGOUTPUTTEXTEDIT_H
 #define DEBUGOUTPUTTEXTEDIT_H
 
-#include <qtextedit.h>
+#include <ktextbrowser.h>
 #include <qpopupmenu.h>
 #include <qpoint.h>
 
@@ -29,7 +29,7 @@ This class is used for showing log content
 
 @author Christoph Thielecke
 */
-class DebugOutputTextEdit : public QTextEdit
+class DebugOutputTextEdit : public KTextBrowser
 {
 	Q_OBJECT
 
