@@ -31,8 +31,7 @@
 EnterUsernamePasswordDialog::EnterUsernamePasswordDialog(QWidget *parent, const QString& caption,bool askForGrouppassword, bool askForUsername) : KDialogBase( parent, "Enter_account_data", true, caption,
 		KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true )
 {
-	Password="";
-	GroupPassword="";
+
 	this->askForGrouppassword = askForGrouppassword;
 	this->askForUsername = askForUsername;
 	
@@ -52,12 +51,10 @@ EnterUsernamePasswordDialog::EnterUsernamePasswordDialog(QWidget *parent, const
 		main->LabelUsername->hide();
 	}
 
-	if (!askForGrouppassword && !askForUsername)
-		main->SaveValuesCheckBox->setText(i18n("Sa&ve password"));
-	else if (askForGrouppassword && !askForUsername)
-		main->SaveValuesCheckBox->setText(i18n("Sa&ve PSK and password"));
-	else if (askForGrouppassword && askForUsername)
-		main->SaveValuesCheckBox->setText(i18n("Sa&ve PSK, username and password"));
+	if (!askForGrouppassword)
+		main->SavePskCheckBox->hide();
+	if (!askForUsername)
+		main->SaveUsernameCheckBox->hide();
 
 	main->textLabel2->setText( QString("<b><font size=\"+1\">"+i18n( "Enter account data:")+"</b></font>" ));
 }
@@ -92,12 +89,7 @@ void EnterUsernamePasswordDialog::accept()
 	}
 	
 	if (ok)
-	{
-		Password= main->PasswordEdit->text();
-		GroupPassword = main->PSKLineEdit->text();
-		Username = main->UsernameEdit->text();
 		QDialog::accept();
-	}
 
 
 }
