@@ -23,6 +23,7 @@
 #include "importcertificatedialogbase.h"
 #include <qprocess.h>
 #include <qstring.h>
+#include <qstringlist.h>
 #include <kdialogbase.h>
 #include "kvpncconfig.h"
 
@@ -51,13 +52,14 @@ class ImportCertificateDialog : public KDialogBase {
 		bool importSuccess;
 		bool doExit;
 
-		enum ImportType {pkcs12_freeswan=0,pkcs12_racoon=1,ca_der=2,pkcs12_openvpn=3};
+		enum ImportType {pkcs12_freeswan=0,pkcs12_racoon=1,ca_der=2,pkcs12_openvpn=3,cisco=4};
 
 protected:
 		QProcess *ImportProcess;
 		KVpncConfig *GlobalConfig;
 		bool done;
 		int askpasscount;
+		QStringList *env;
 
 	public slots:
 		void accept();
@@ -71,6 +73,7 @@ protected:
 		void doCacert();
 		void doPrivateKey();
 		void doCreateHash();
+		void ciscoCertMgrExited();
 
 
 	public:
