@@ -226,9 +226,9 @@ void ImportOpenvpnProfileDialog::canAccept() {
 	if ( OpenvpnConfigFile.open( IO_ReadOnly ) ) {
 		VpnAccountData::ConnectionType ConnType = VpnAccountData::openvpn;
 		acc = new VpnAccountData ( ConnType, "" );
-		QString profilename = filename.section( '/', -1, -1 ).section( '.', -2, -2 );
+		QString profilename = Utils(config).removeSpecialCharsForFilename(filename).section( '/', -1, -1 ).section( '.', -2, -2 );
 		acc->setName( profilename ); // /home/user/openvpn/CompanyABC.conf -> CompanyABC
-		acc->setDescription( i18n( "Imported from %1" ).arg( filename.section( '/', -1, -1 ) ) );
+		acc->setDescription( i18n( "Imported from %1" ).arg( Utils(this->config).removeSpecialCharsForFilename( filename).section( '/', -1, -1 ) ) );
 		acc->setLocalPort( 1194 );
 		acc->setAuthWithUsernameAndPassword( false );
 		acc->setRemoteNetMask( "24" );
@@ -550,7 +550,7 @@ void ImportOpenvpnProfileDialog::canAccept() {
 // 		if ( !acc->getCaCertificate().isEmpty() && !acc->getCaCertificate().startsWith( CertPath ) ) {
 // 			QString prefix = "./";
 // 			if ( !filename.find( '/' ) > -1 )
-// 				prefix = QString( filename.section( '/', 0, -2 ) + "/" );
+// 				prefix = QString( Utils(this->GlobalConfig).removeSpecialCharsForFilename( filename).section( '/', 0, -2 ) + "/" );
 // 
 // 			QFile CaCertFileSrc ( prefix + acc->getCaCertificate() );
 // 			QFile CaCertFileDst ( QString( CertPath + "/openvpnimport_" + acc->getCaCertificate() ) );
@@ -586,7 +586,7 @@ void ImportOpenvpnProfileDialog::canAccept() {
 // 		if ( !acc->getX509Certificate().isEmpty() && !acc->getX509Certificate().startsWith( CertPath ) ) {
 // 			QString prefix = "./";
 // 			if ( !filename.find( '/' ) > -1 )
-// 				prefix = QString( filename.section( '/', 0, -2 ) + "/" );
+// 				prefix = QString( Utils(this->GlobalConfig).removeSpecialCharsForFilename(filename).section( '/', 0, -2 ) + "/" );
 // 
 // 			QFile X509CertFileSrc ( prefix + acc->getX509Certificate() );
 // 			QFile X509CertFileDst ( QString( CertPath + "/openvpnimport_" + acc->getX509Certificate() ) );
@@ -622,7 +622,7 @@ void ImportOpenvpnProfileDialog::canAccept() {
 // 		if ( !acc->getPreSharedKey().isEmpty() && !acc->getPreSharedKey().startsWith( CertPath ) ) {
 // 			QString prefix = "./";
 // 			if ( !filename.find( '/' ) > -1 )
-// 				prefix = QString( filename.section( '/', 0, -2 ) + "/" );
+// 				prefix = QString( Utils(this->GlobalConfig).removeSpecialCharsForFilename( filename).section( '/', 0, -2 ) + "/" );
 // 
 // 			QFile PreSharedKeyFileSrc ( QString( prefix + acc->getPreSharedKey() ) );
 // 			QFile PreSharedKeyFileDst ( QString( CertPath + "/openvpnimport_" + acc->getPreSharedKey() ) );
