@@ -139,13 +139,6 @@ void ImportProfileDialog::canAccept()
 	PeerTimeout = 90
 	EnableLocalLAN = 1 // only reading because we dont want to do this
 	EnableSplitDNS = 1
-
-	// cert is not supported yet by vpnc: not action taken
-	CertStore=1
-	CertName=VPN Client
-	VerifyCertDn=CN="vpn.uni-jena.de", OU="Computer Center", O="University Jena", C="DE"
-	SendCertChain=1
-
 	*/
 	QString Description = config.readEntry( "Description", "" );
 
@@ -169,10 +162,7 @@ void ImportProfileDialog::canAccept()
 			GlobalConfig->appendLogEntry(i18n("PCF import: gateway found: %1").arg(Gateway), GlobalConfig->debug);
 	}
 
-	int AuthType = config.readNumEntry( "AuthType" , -1 );
 
-	if (AuthType==-1)
-		AuthType = config.readNumEntry( "!AuthType", -1 );
 
 	QString GroupName = config.readEntry( "GroupName" , "" );
 
@@ -267,15 +257,21 @@ void ImportProfileDialog::canAccept()
 	QString BackupServer = config.readEntry( "BackupServer", "" );
 	bool enableMSLogon = config.readBoolEntry( "EnableMSLogon", FALSE );
 	//	int TunnelingMode = config.readNumEntry( "TunnelingMode", -1 );
-	int TunnelingPort = config.readNumEntry( "TcpTunnelingPort", -1 ); //std::cout << "tunneling port: " << TunnelingPort << std::endl;
+	int TcpTunnelingPort = config.readNumEntry( "TcpTunnelingPort", 10000 ); //std::cout << "tunneling port: " << TunnelingPort << std::endl;
+	int TunnelingPort = config.readNumEntry("TunnelingPort",10000);
 	//	int CertStore = config.readNumEntry( "CertStore", -1 );
 	QString CertName = config.readEntry( "CertName", "" );
+
+	if (GlobalConfig->KvpncDebugLevel > 0)
+		GlobalConfig->appendLogEntry(i18n("PCF import: certificate name found: %1").arg(CertName), GlobalConfig->debug);
+
 	QString CertPath = config.readEntry( "CertPath", "" );
 	QString CertSubjectName = config.readEntry( "CertSubjectName", "" );
 	QString CertSerialHash = config.readEntry( "CertSerialHash", "" );
 	//	bool SendCertChain = config.readBoolEntry( "SendCertChain" , "" );
 	//	bool VerifyCertDN = config.readBoolEntry( "VerifyCertDN", FALSE );
 	int DHGroup = config.readNumEntry( "DHGroup", -1 );
+	int LocalPort=500;
 
 	if (GlobalConfig->KvpncDebugLevel > 0)
 		GlobalConfig->appendLogEntry(i18n("PCF import: Diffie Hellman group found: %1").arg(QString().setNum(DHGroup)), GlobalConfig->debug);
@@ -301,13 +297,17 @@ void ImportProfileDialog::canAccept()
 	bool usePerfectSecrecy = false;
 	bool useSingleDes = false;
 	bool useLocalPort = false;
+	bool useUdpPort= true;
 
 	bool useNtDomainName = false;
 	if ( enableMSLogon && !NtDomain.isEmpty() )
 		useNtDomainName = true;
 
-// 	if ( TunnelingPort != -1 )
-// 		useLocalPort = true;
+// 	if ( TunnelingPort != 10000 )
+// 	{
+// 		useUdp=true; //FIXME: is this right? I guess its only on udp
+// 		useUdpPort = true;
+// 	}
 
 	bool useIkeGroup = false;
 	QString IkeGroup;
@@ -358,10 +358,45 @@ void ImportProfileDialog::canAccept()
 	bool useApplicationVersion = false;
 	bool useGlobalIpsecSecret = false;
 
+
 	VpnAccountData::ConnectionType ConnType = VpnAccountData::cisco;
 
 	acc = new VpnAccountData ( ConnType, Utils(this->GlobalConfig).removeSpecialCharsForFilename( GroupName).stripWhiteSpace() );
 
+	/*
+	AuthType=
+	The authentication type of the user:
+	1 = Pre-shared keys (default)
+	3 = Digital Certificate using an RSA signature.
+	5 = Mutual authentication (hybrid)
+	*/
+	int AuthType = config.readNumEntry( "AuthType" , -1 );
+
+	if (AuthType==-1)
+		AuthType = config.readNumEntry( "!AuthType", -1 );
+
+ 	if (GlobalConfig->KvpncDebugLevel > 0)
+		if (AuthType ==1)
+			GlobalConfig->appendLogEntry(i18n("PCF import: authentication type found: %1").arg(i18n("PSK")), GlobalConfig->debug);
+		if (AuthType ==3)
+			GlobalConfig->appendLogEntry(i18n("PCF import: authentication type found: %1").arg(i18n("certificate")), GlobalConfig->debug);
+		if (AuthType ==5)
+			GlobalConfig->appendLogEntry(i18n("PCF import: authentication type found: %1").arg(i18n("hybrid")), GlobalConfig->debug);
+
+	if (AuthType == 3 || AuthType == 5)
+	{
+		// vpnc has no cert support :(
+		acc->setConnectionType (VpnAccountData::ciscoorig);
+		acc->setAuthType( VpnAccountData::cert);
+
+		if (!CertName.isEmpty())
+			acc->setX509Certificate(CertName);
+	}
+	if (AuthType == 1 )
+		acc->setAuthType( VpnAccountData::psk);
+
+
+
 	acc->setDescription( Description );
 	acc->setGateway( Gateway );
 	acc->setID( GroupName );
@@ -370,7 +405,7 @@ void ImportProfileDialog::canAccept()
 	acc->setUserPassword( UserPassword );
 	acc->setSaveUserPassword( saveUserPassword );
 	acc->setSavePsk( saveGroupPwd );
-	acc->setNtDomainName(	NtDomain );
+	acc->setNtDomainName( NtDomain );
 	acc->setPerfectForwardSecrety( PerfectForwardSecrecy );
 	acc->setIkeGroup( IkeGroup );
 	acc->setUseApplicationVersion( useApplicationVersion );
@@ -385,16 +420,16 @@ void ImportProfileDialog::canAccept()
 	acc->setUseUdp( useUdp );
 // 	acc->setUdpPort( 10000 );
 
-	// FIXME what is psk and what is cert?
-	acc->setAuthType( VpnAccountData::psk);
-
-
-
 	if (useLocalPort){
-		acc->setLocalPort(TunnelingPort);
+		acc->setLocalPort(LocalPort);
 		acc->setUseLocalPort(true);
 	}
 
+// 	if (useUdpPort){
+// 		acc->setUdpPort(TunnelingPort);
+// 		acc->setUseUdpPort(true);
+// 	}
+
 	if (PeerTimeout > -1 )
 	{
 		// read minutes but store seconds
