@@ -120,6 +120,13 @@ protected:
 	*/
 	virtual bool queryExit();
 
+	void saveProperties( KConfig* );
+	void readProperties( KConfig* );
+
+public:
+	void restore(KConfig *config, int i);
+	void restore();
+
 	/**
 	* return the user id of the certificate
 	*	@param Cert certificate from wich should be extracted
@@ -143,12 +150,14 @@ private:
 	KAction* ConnectAction; //< connect action
 	KAction* DisconnectAction; //< disconnect action
 	KAction *NewSessionAction;
-	//	KAction *AdvancedSessionAction;
 	KAction *SaveSessionAction;
 	KAction *DeleteSessionAction;
 	KAction *ImportSessionAction;
 	KAction *ImportOpenvpnProfileAction;
 	KAction *ExportOpenvpnProfileAction;
+	KAction *ImportFreeswanProfileAction;
+	KAction *ImportKvpncSettingsAction;
+	KAction *ExportKvpncSettingsAction;
 	KAction *ImportCertAction;
 	KAction *SelectAction; //< line select action
 	KAction *ProfileManagerAction;
@@ -159,6 +168,8 @@ private:
 	KAction *ReportBugAction;
 	KAction *SendFeedbackMailAction;
 	KAction *PreferencesAction; //< show preferences dialog
+	KAction *ManageCiscoCertAction; //< show cisco cert manager
+	KAction *CiscoCertEnrollmentAction; //< show cisco cert enrollment dialog
 	KToggleAction *ToolsInfoAction;
 	KToggleAction *LogViewerAction;
 	KToggleAction *ShowToolbarAction; //< toggle toolbar on/off
@@ -187,8 +198,12 @@ private:
 	bool testOldPppdStyle;
 	bool shutdownIsCalled;
 	bool testPppdReplacedefaultroute;
+	bool testPppdRequireMppe128;
+	bool pppdHasRequireMppe128Support;
 	bool pppdHasReplacedefaultrouteSupport;
 	bool stopContinue; //< if something happens that causes to abort now
+	bool ciscoVpncRunning; //< true if vpnclient is started and cipsec0 is up
+	bool showProfilesOnly; //< if true only the profiles will shown in preferencesdialog
 
 	QString OldDefaultroute;
 	QString VpncConnectScript;
@@ -209,6 +224,7 @@ private:
 	QString TmpDns1;
 	QString TmpDns2;
 	QString VpncDevice;
+	QString CiscoVpncDevice;
 	QString PppdDevice;
 	QString OpenvpnDevice;
 	QString IpsecType; //< openswan, strongswan, freeswan
@@ -216,6 +232,7 @@ private:
 
 	QProcess *ConnectProcess;
 	QProcess *DisconnectProcess;
+	QProcess *CiscoVpncProcess;
 	QProcess *RacoonProcess;
 	QProcess *IpsecProcess;
 	QProcess *PingProcess;
@@ -228,11 +245,16 @@ private:
 	QProcess *CmdBeforeDisconnectProcess;
 	QProcess *CmdAfterConnectProcess;
 	QProcess *CmdAfterDisconnectProcess;
+	QProcess *SetFirewallAfterConnectProcess;
+	QProcess *SetFirewallBeforeDisconnectProcess;
+
+
 	QProcess *RouteProcess;
 	QProcess *SetVirtualIPProcess;
 	QProcess *ReplaceDefaultRouteProcess;
 	QProcess *ConnectionStatusCheckProcess;
 	QProcess *TestPppdProcess;
+	QProcess *TestCiscoVpncProcess;
 	QProcess *IptablesProcess;
 	QProcess *KillProcess;
 	QProcess *PptpRouteProcess;
@@ -243,10 +265,10 @@ private:
 	QProcess *RemoveSetkeyProcess;
 	QProcess *BugReportProcess;
 	QProcess *DonateProcess;
+	QProcess *VtundProcess;
 
 	int TimeOutProcess; //< for timeout
 	int ConnectingProcess; //< for killing process
-	QTime connectionTime;
 	QPixmap connectedIcon;
 	QPixmap disconnectedIcon;
 	QPixmap connectingIcon;
@@ -309,6 +331,7 @@ private slots:
 	void slotConnectTimedOut();
 	void slotDurationEvent();
 	void readOutputFrom_vpnc();
+	void readOutputFrom_ciscovpnc();
 	void wroteToStdin_vpncConfig();
 	void readFromStdout_disconnect();
 	void readFromStderr_disconnect();
@@ -323,6 +346,8 @@ private slots:
 	void readFromStdout_l2tpd();
 	void readFromStderr_l2tpd();
 	void readOutput_openvpn();
+	void readFromStdout_vtun();
+	void readFromStderr_vtun();
 	void readFromStdout_tail_racoon();
 	void readFromStderr_tail_racoon();
 	void readOutputFromTail_ipsec();
@@ -337,13 +362,18 @@ private slots:
 	void readFromStdout_connectionStatusCheck();
 	void readFromStderr_connectionStatusCheck();
 	void readPppdtestProcessOutput();
+	void readCiscoVpncTestProcessOutput();
 	void quitCalled();
 	void quitCalledKicker();
-	void advancedSettingsClicked();
 	void pptpProcessExited();
+	void vtun_exited(); //< vtund has been exited
 	void prepareL2tpd(); //< write l2tpd conf etc.
 	
 	void importProfileClicked(); //< PCF import
+	void importIpsecProfileClicked ();
+
+	void importKvpncSettingsClicked();
+	void exportKvpncSettingsClicked();
 
 	void importOpenvpnProfileClicked(); //< OpenVPN config file import
 	void doRacoon();
@@ -370,11 +400,15 @@ private slots:
 	void openvpnStarted();
 	void openSSLEnded();
 	void importCertClicked();
+	void manageCiscoCertClicked();
+	void enrollCiscoCertClicked();
 	void showProfileManagerClicked();
 	void executeCommandBeforeConnect();
 	void executeCommandAfterConnect();
 	void executeCommandBeforeDisconnect();
 	void executeCommandAfterDisconnect();
+	void setFirewallAfterConnect();
+	void setFirewallBeforeDisconnect();
 	void slotConnecting();
 	void toggleDebugConsole();
 	void addAdditionalNetworkRoutes();
@@ -390,11 +424,16 @@ private slots:
 	void sendFeedbackMail();
 	void feedbackMailSent();
 	void start_l2tpd();
+	bool checkCiscoVpncStatus();
+	void startCiscoVpnc();
 	
 public:
 	void importOpenvpnProfileClicked(QString file); //< OpenVPN config file import
 	void importProfileClicked(QString file); //< PCF import
 
+	bool backupResolvConf();
+	bool restoreResolvConf();
+
 public:
 k_dcop:
 	QString getVersion();
