@@ -32,6 +32,7 @@
 #include <qtextstream.h>
 #include <qtextedit.h>
 #include <qcolor.h>
+#include <qstringlist.h>
 #include <kconfig.h>
 #include <kwallet.h>
 #include <kstatusbar.h>
@@ -61,6 +62,7 @@ public:
 	enum LogType {info=0, remote=1, error=2, success=3, debug=4};
 
 	QString pathToVpnc;
+	QString pathToCiscoVpnc;
 	QString pathToRacoon;
 	QString pathToSetkey;
 	QString pathToIptables;
@@ -69,6 +71,7 @@ public:
 	QString pathToPppd;
 	QString pathToPptp;
 	QString pathToL2tpd;
+	QString pathToXl2tpd;
 	QString pathToKill;
 	QString pathToKillall;
 	QString pathToPing;
@@ -78,12 +81,15 @@ public:
 	QString pathToRoute;
 	QString pathToNetstat;
 	QString pathToPkcs11Tool;
+	QString pathToVtund;
+	QString pathToCiscoCertMgr;
 	QString AutoConnectProfile;
 	QString RacoonDebugLevel;
 	QString Vpnc_pid_file;
 	QString Pppd_pid_file;
 	QString lastProfile;
 	QString logfileName;
+	QString InterpreterShell;
 
 	QString TmpPassword; //< from enter password dialog
 	QString TmpGroupPassword; //< from enter password dialog
@@ -94,6 +100,9 @@ public:
 	QString TmpPrivateKeyPass;
 	QString TmpHttpProxyPassword;
 
+	QString OldDefaultGw; //< default gw before connect
+	QString OldDefaultDev; //< default gw dev before connect
+
 	bool minimizeAfterConnect;
 	bool showDebugConsole;
 	bool writeLogFile;
@@ -102,6 +111,9 @@ public:
 	bool holdGeneratedScripts;
 	bool programsInPath;
 	bool enableDebugPppd;
+	bool enableDebugPptpd;
+	bool enableDebugL2tpd;
+	bool enableDebugXl2tpd;
 	bool enableFreeswanVerbose;
 	bool enableDebugOpenvpn;
 	bool useColorizedLogOutput;
@@ -119,12 +131,14 @@ public:
 	bool hideOnCloseInfo;
 	bool feedbackMailSent;
 	bool doKillL2tpdIfStillRunning; //< kill l2tpd if its still running and not started from kvpnc
+	bool doKillXl2tpdIfStillRunning; //< kill xl2tpd if its still running and not started from kvpnc
 	bool doKillRacoonIfStillRunning; //< kill racoon if its still running and not started from kvpnc
+	bool showConnectionTimeInTooltip; //< True if the connection duration should be shown in kicker tooltip 
 
 	int VpncDebugLevel;
 	int KvpncDebugLevel;
 	int OpenvpnDebugLevel;
-	int PptpDebugLevel;
+	int PptpLogLevel;
 	int LogViewerFontSize;
 	int mainwindow_pos_x;
 	int mainwindow_pos_y;
@@ -137,6 +151,8 @@ public:
 	int runningCheckCounter;
 	int runningCheckTimeout;
 	int OpenvpnManagementPort;
+	int AuthRetryCount; //< count of autn retry
+
 	QPtrList<ToolInfo> *ToolList;
 	QPtrList<VpnAccountData> *AccountList;
 	VpnAccountData *currentProfile;
@@ -146,6 +162,7 @@ public:
 	QColor ErrorLogColor;
 	QColor SuccessLogColor;
 	QColor DebugLogColor;
+	QColor DebugBackgroundcolor;
 
 	QApplication *appPointer;
 	QPoint pos;
@@ -158,8 +175,12 @@ public:
 
 	QPoint WindowPos;
 	QSize WindowSize;
-
-	QColor DebugBackgroundcolor;
+	struct IpsecImportSection {
+		QString SectionName;
+		QStringList SectionData;
+	};
+	
+	QPtrList<VpnAccountData> *ImportedAccountList;
 
 	QWidget *parent;
 	KStatusBar *statusbar;
@@ -199,10 +220,18 @@ public:
 	 */
 	void removeEntry(QString Name);
 
+	VpnAccountData* findProfile(QPtrList<VpnAccountData> *list,const QString& Name);
+	QString removeWhiteSpaceAtBegin(const QString);
+
 	void slotStatusMsg( const QString &text, int id = ID_STATUS_MSG );
 	void doBackupConfig();
 	void restoreBackupConfig();
 
+	bool exportKvpncConfig(QString filename);
+	bool importKvpncConfig(QString filename); //< true if profiles imported
+
+	bool importIpsecConfig(QString filename );
+
 };
 
 #endif
