@@ -23,6 +23,8 @@
 #include "logviewerdialogbase.h"
 #include <kdialogbase.h>
 #include <qstring.h>
+#include <qstringlist.h>
+#include <qvaluevector.h>
 #include "kvpncconfig.h"
 #include <qapplication.h>
 
@@ -33,17 +35,25 @@ class LogViewerDialog : public KDialogBase
 {
 	Q_OBJECT
 public:
-	LogViewerDialog(QWidget *parent,QApplication *app, KVpncConfig *GlobalConfig, const QString& caption);
+	LogViewerDialog(QWidget *parent,QApplication *app, KVpncConfig *GlobalConfig, const QString& caption, int count);
 
 	~LogViewerDialog();
+	void showLogPart(int start, int count,bool parseLogType=true);
 
 public slots:
 	void accept();
+	void parseLog();
+	void updateLineCountClicked();
+	void findLogEntryClicked();
+	void find(QString what);
 
 private:
 	LogViewerDialogBase *main;
 	KVpncConfig *GlobalConfig;
 	QApplication *app;
+	QValueVector<QString> LogList;
+	int linecount;
+	
 };
 
 #endif
