@@ -22,6 +22,8 @@
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 #include <kmessagebox.h>
+#include <kmainwindow.h>
+#include <kapp.h>
 
 #include <klocale.h>
 #include <dcopclient.h>
@@ -30,7 +32,7 @@
 // App includes
 #include "kvpnc.h"
 static const char *description =
-    I18N_NOOP( "KDE frontend for various vpn clients\nCurrently supported protocols:\n* Cisco\n* IPSec (FreeS/WAN, Openswan, strongSwan, racoon)\n* PPTP\n* OpenVPN\n* L2TP over IPSec (racoon, FreeS/WAN, Openswan, strongSwan)" );
+    I18N_NOOP( "KDE frontend for various vpn clients\nCurrently supported protocols:\n* Cisco (vpnc (free), vpnclient (propritary))\n* IPSec (FreeS/WAN, Openswan, strongSwan, racoon)\n* PPTP\n* OpenVPN\n* L2TP over IPSec (racoon, FreeS/WAN, Openswan, strongSwan)\n* Vtun" );
 // QDate().fromString(, Qt::LocalDate ).toString( "yyyyMMdd" )
 QString date (__DATE__);
 QString day= date.section(' ',0,0);
@@ -42,7 +44,7 @@ QString currentdate ( "+SVN(" + date+" "+ QTime().fromString(QString (__TIME__))
 
 #define __is_release__
 
-QString versionstring1 = "0.8.9";
+QString versionstring1 = "0.9.0";
 
 #ifdef __is_release__
 static const char *KVPNCVERSION = versionstring1.ascii();
@@ -88,62 +90,61 @@ int main( int argc, char *argv[] ) {
 	aboutData.addCredit( "Marc Serra Romero" , I18N_NOOP( "Catalan translation" ), "mad93@majomo.com" );
 	aboutData.addCredit( "Buelent SENER" , I18N_NOOP( "Turkish  translation" ), "bsener@inonu.edu.tr" );
 	aboutData.addCredit( "Laurent Montel", I18N_NOOP( "Patches" ), "montel@kde.org" );
-	aboutData.addCredit( "Peter Kussmann" , I18N_NOOP( "Test environment, OpenVPN testing, new ideas" ), "peter.kussmann@gmx.de" );
+	aboutData.addCredit( "Peter Kumann" , I18N_NOOP( "Test environment, OpenVPN testing, new ideas" ), "peter.kussmann@gmx.de" );
 	aboutData.addCredit( "D. Klinkenberg" , I18N_NOOP( "Testing PPTP, usebility hints & tests, bug hunting" ), "d.klinkenberg@gmx.net" );
 	aboutData.addCredit( "Lenon Kitchens" , I18N_NOOP( "Testing OpenSWAN, bug hunting" ), "lenon@sanctuary.org" );
 	aboutData.addCredit( "Fathi Boudra" , I18N_NOOP( "Testing OpenVPN, bug hunting" ), "fboudra@free.fr" );
 	aboutData.addCredit( "HAL9000" , I18N_NOOP( "Cisco password decoder" ), "hal9000@evilscientists.de" );
 	aboutData.addCredit( "Marcin Prejsnar" , I18N_NOOP( "Testing OpenVPN auth+cert, bug hunting" ), "alex@pronet.pl" );
 	aboutData.addCredit( "Elias Probst" , I18N_NOOP( "Icon artwork, bug hunting" )," elias.probst@gmx.de" );
-
-
-	KCmdLineArgs::init( argc, argv, &aboutData );
-	KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
-
-	KApplication a;
-
-	// Broken on request from Eric M.
-	//  if(a.isRestored()) {
-	//    RESTORE(KVpnc);
-	//  } else {
-	/*
-	if (getenv("USER") != "root"){
-		KMessageBox::error( 0, I18N_NOOP( "Kvpnc must be started as root!" ) );
-		exit(0);
-	}
-	*/
+	aboutData.addCredit( "Andreas Diestelmann" , I18N_NOOP( "Support KVpnc development with 15EUR" ),"andreas@diestelmann.de" );
+	aboutData.addCredit( "Frank Visconti" , I18N_NOOP( "Support KVpnc development with 30$" ),"frank3@viscontifamily.net" );
+	aboutData.addCredit( "Attila Ruzsinszky" , I18N_NOOP( "Cisco testbed, bug hunting"), "<ruzsinszky.attila@gmail.com>" );
+	aboutData.addCredit( "Christiansen" , I18N_NOOP( "Danish translation"), "<susebruger@mailme.dk>" );
 
 	// Initialize command line args
 	KCmdLineArgs::init( argc, argv, "kvpnc", "kvpnc", description, versionstring1.ascii() );
 
-	// Tell which options are supported
-	KCmdLineArgs::addCmdLineOptions( options );
-
 	// Add options from other components
 	KApplication::addCmdLineOptions();
+	KCmdLineArgs::addCmdLineOptions( options );
 
-	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+	KApplication a;
+	KVpnc *kvpnc =  new KVpnc( &a );
 
-
-
-	KVpnc *kvpnc = new KVpnc( &a );
-	a.setMainWidget( kvpnc );
 	DCOPClient* dcop = a.dcopClient();
 	dcop->attach();
 	dcop->registerAs( "kvpnc" );
 	dcop->setNotifications( true );
 
-
-	if ( args->isSet( "openvpnimport" ) ) {
-		QString openvpnimportfile = QString( args->getOption( "openvpnimport" ) );
-		kvpnc->importOpenvpnProfileClicked( openvpnimportfile );
-	} 
-	else if ( args->isSet( "ciscoimport" ) ) {
-		QString ciscoimportfile = QString( args->getOption( "ciscoimport" ) );
-		kvpnc->importOpenvpnProfileClicked( ciscoimportfile );
+	// Broken on request from Eric M.
+	if (a.isSessionRestored())
+	{
+		kvpnc->restore();
 	}
+	else
+	{
+// 		if (getenv("USER") != "root")
+// 		{
+// 			KMessageBox::error( 0, I18N_NOOP( "Kvpnc must be started as root!" ) );
+// 			exit(0);
+// 		}
+		
+		KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+		
+		a.setMainWidget( kvpnc );
 
-	//  }
+		if ( args->isSet( "openvpnimport" ) ) {
+			QString openvpnimportfile = QString( args->getOption( "openvpnimport" ) );
+			kvpnc->importOpenvpnProfileClicked( openvpnimportfile );
+		}
+		else if ( args->isSet( "ciscoimport" ) ) {
+			QString ciscoimportfile = QString( args->getOption( "ciscoimport" ) );
+			kvpnc->importOpenvpnProfileClicked( ciscoimportfile );
+		}
+
+		}
 	int ret = a.exec();
 	return ret;
 }
+
