@@ -51,7 +51,7 @@ NetworkInterface::NetworkInterface( KVpncConfig* GlobalConfig,QApplication *app,
 	defaultinterface="default";
 	readOutput=false;
 	env = new QStringList();
-	*env << "LC_ALL=C" << "LANG=C";
+	*env << "LC_ALL=C" << "LANG=C" << "PATH=/bin:/usr/bin:/usr/sbin:/sbin";
 	this->GlobalConfig = GlobalConfig;
 }
 
@@ -200,7 +200,7 @@ QString NetworkInterface::getInterfaceAddress( QString IPforInterface )
 
 
 			InterfaceAddressProc = new QProcess(this);
-			InterfaceAddressProc->addArgument( "/bin/sh" );
+			InterfaceAddressProc->addArgument( GlobalConfig->InterpreterShell );
 			InterfaceAddressProc->addArgument(GetIpForInterfaceScript);
 			retrieveInterfaceAddress=true;
 			readOutput=true;
