@@ -74,6 +74,7 @@ public:
 	 */
 	QString getInterfaceIP(QString Interface);
 
+	QString getInterfaceIP2(QString Interface); // old style
 	/**
 	 *     Gets the device from a given IP
 	 * @param IP The IP which the target interface has
@@ -109,13 +110,16 @@ public slots:
 	void readFromStdout();
 	void readFromStderr();
 	void processHasFinished();
+	void readFromStdout_interfaceip();
+	void readFromStderr_interfaceip();
 	void externalIpDataRecieved(const QHttpResponseHeader & resp);
 
 protected:
 	QProcess *proc; //< The process for starting external programs
 	QProcess *InterfaceExitsProc;
+	QProcess *InterfaceIpProc;
 	bool interfaceTest; //< True if interface test is running
-	
+	bool retrieveInterfaceIP; //< True if retrieve interface IP is running
 	bool retrieveInterfaceAddress; //< True if retrieve interface address is running
 	QStringList InterfaceList; //< List with interfaces
 	QString InterfaceIP; //< IP for interface
