@@ -38,7 +38,6 @@
 
 #include "networkinterface.h"
 #include "importcertificatedialog.h"
-#include "advancedsettingsdialog.h"
 #include "importprofiledialog.h"
 #include "vpnaccountdata.h"
 
@@ -639,63 +638,6 @@ void NewProfileDialog::profileNameChanged( const QString& )
 	// 		buttonOk->setEnabled( TRUE );
 }
 
-void NewProfileDialog::advancedSettingsClicked()
-{
-	VpnAccountData::ConnectionType connectionType;
-	if (main->ConnectionTypeComboBox->currentItem() == VpnAccountData::ConnectionType(VpnAccountData::cisco))
-		connectionType = VpnAccountData::ConnectionType(VpnAccountData::cisco);
-	else if (main->ConnectionTypeComboBox->currentItem() == VpnAccountData::ConnectionType(VpnAccountData::racoon))
-		connectionType = VpnAccountData::ConnectionType(VpnAccountData::racoon);
-	else if (main->ConnectionTypeComboBox->currentItem() == VpnAccountData::ConnectionType(VpnAccountData::freeswan))
-		connectionType = VpnAccountData::ConnectionType(VpnAccountData::freeswan);
-	else if (main->ConnectionTypeComboBox->currentItem() == VpnAccountData::ConnectionType(VpnAccountData::pptp))
-		connectionType = VpnAccountData::ConnectionType(VpnAccountData::pptp);
-	else
-		connectionType = VpnAccountData::ConnectionType(VpnAccountData::other);
-
-	AdvancedSettingsDialog d1(this, i18n("Advanced Settings"),profileData,connectionType,GlobalConfig);
-
-	d1.main->SingleDesCheckbox->setChecked( profileData->getUseSpecialRemoteID() );
-	d1.main->IkeGroupCheckbox->setChecked ( profileData->getUseIkeGroup() );
-
-	d1.main->PerfectForwardSecurityCheckbox->setChecked( profileData->getUsePerfectForwardSecrety() );
-	d1.main->ApplicationVersionCheckbox->setEnabled ( profileData->getUseApplicationVersion() );
-
-	d1.main->IkeGroupCombobox->setCurrentText( profileData->getIkeGroup() );
-	d1.main->PerfectForwardSecrecyCombobox->setCurrentText( profileData->getPerfectForwardSecrety() );
-	d1.main->ApplicationVersionLineedit->setText( profileData->getApplicationVersion() );
-
-	d1.main->AdvancedSettingsCheckbox->setChecked ( profileData->getUseAdvancedSettings());
-
-	if ( profileData->getUseAdvancedSettings() )
-	{
-		if (profileData->connectiontype == VpnAccountData::cisco)
-		{
-			d1.main->PerfectForwardSecurityCheckbox->setEnabled ( true );
-			d1.main->SingleDesCheckbox->setEnabled ( true );
-			d1.main->ApplicationVersionCheckbox->setEnabled ( true );
-		}
-
-
-		d1.main->IkeGroupCheckbox->setChecked ( profileData->getUseIkeGroup() );
-		d1.main->SingleDesCheckbox->setChecked( profileData->getUseSingleDes() );
-		d1.main->IkeGroupCheckbox->setChecked ( profileData->getUseIkeGroup() );
-		d1.main->PerfectForwardSecurityCheckbox->setChecked( profileData->getUsePerfectForwardSecrety() );
-
-		if ( profileData->getUseApplicationVersion() )
-		{
-			d1.main->ApplicationVersionLineedit->setEnabled ( true );
-			d1.main->ApplicationVersionCheckbox->setChecked( true );
-		}
-
-
-		d1.main->IkeGroupCombobox->setEnabled (  profileData->getUseIkeGroup() );
-	}
-
-	d1.exec();
-	d1.connectionType = connectionType;
-}
-
 QString NewProfileDialog::getName()
 {
 	return Name;
