@@ -44,6 +44,7 @@
 #include "newprofilewizardopenvpnauth.h"
 #include "newprofilewizardopenvpnselection.h"
 #include "newprofilewizardpptp.h"
+#include "profilevtunoptions.h"
 #include "newprofilewizardauthselection.h"
 #include "newprofilewizardpsk.h"
 #include "newprofilewizardcert.h"
@@ -56,6 +57,7 @@
 #include "importcertificatedialog.h"
 #include "newprofilewizardconnectoptions.h"
 #include "newprofilewizardconnectionstatuscheck.h"
+#include "profilenetworkvirtualipoptions.h"
 
 //END INCLUDES
 
@@ -114,6 +116,12 @@ public slots:
 	void useSmartcardOnCertFormateToggled(bool);
 	void detectPkcs11Ids();
 	void detectPkcs11Slots();
+	void mtuToggled(bool);
+	void mruToggled(bool);
+	void useVirtualIpAddressToggled(bool);
+	void localIDTypeToggled(const QString&);
+	void usePortToggled(bool);
+	void useAuthenticationAlgorithmToggled(bool);
 	//void reject();
 
 protected:
@@ -157,7 +165,7 @@ protected:
 private:
 	void setupPages();
 	bool importProfile(VpnAccountData::ConnectionType ConnType);
-	bool importP12Certificate();
+	bool importCertificate();
 	QHBox *page1;
 	QHBox *newprofilewizardtypeselectionpage;
 	QHBox *newprofilewizardgeneralpage;
@@ -169,12 +177,14 @@ private:
 	QHBox *newprofilewizardopenvpnselectionpage;
 	QHBox *newprofilewizardopenvpnauthpage;
 	QHBox *newprofilewizardpptppage;
+	QHBox *newprofilewizardvtunpage;
 	QHBox *newprofilewizardauthselectionpage;
 	QHBox *newprofilewizardpskpage;
 	QHBox *newprofilewizardcertpage;
 	QHBox *newprofilewizardp12certselectionpage;
 	QHBox *newprofilewizarduserpage;
 	QHBox *newprofilewizardnetworkpage;
+	QHBox *newprofilewizardvirtualipaddresspage;
 	QHBox *newprofilewizardnetworkroutepage;
 	QHBox *newprofilewizardnatpage;
 	QHBox *newprofilewizardconnectionstatuscheckpage;
@@ -190,6 +200,7 @@ private:
 	NewProfileWizardOpenvpnAuth *newprofilewizardopenvpnauthpagecontent;
 	NewProfileWizardOpenvpnSelection *newprofilewizardopenvpnselectionpagecontent;
 	NewProfileWizardPptp *newprofilewizardpptppagecontent;
+	ProfileVtunOptions *newprofilewizardvtunpagecontent;
 	NewProfileWizardAuthSelection *newprofilewizardauthselectioncontent;
 	NewProfileWizardPsk *newprofilewizardpskcontent;
 	NewProfileWizardCert *newprofilewizardcertcontent;
@@ -201,6 +212,7 @@ private:
 	NewProfileWizardNat *newprofilewizardnatcontent;
 	NewProfileWizardConnectionStatusCheck *newprofilewizardconnectionstatuscheckcontent;
 	NewProfileWizardConnectOptions *newprofilewizardconnectoptionscontent;
+	ProfileNetworkVirtualIpOptions *profilenetworkvirtualipoptionscontent;
 	KVpncConfig* GlobalConfig; //< pointer to global config class
 	QWidget* currentpage; // pointer to current page
 	QWidget* previouspage; //< pointer to previous page
