@@ -38,6 +38,7 @@ OpenvpnManagementHandler::OpenvpnManagementHandler( QObject *, KVpncConfig *Glob
 {
 	this->GlobalConfig = GlobalConfig;
 	fInHold = false;
+	gotGreeting=false;
 	connectedToManagementPort=false;
 	errormsg="";
 
@@ -88,12 +89,18 @@ void OpenvpnManagementHandler::socketClosed()
 void OpenvpnManagementHandler::socketConnected()
 {
 
+	connect( socket, SIGNAL( connectionClosed() ), this, SLOT( socketConnectionClosed() ) );
+	connect( socket, SIGNAL( readyRead() ), this, SLOT( socketReadyRead() ) );
+
 // 	KMessageBox::error ( 0, QString("bar"), QString("foo") );
 	connectedToManagementPort=true;
 
 	if ( GlobalConfig->KvpncDebugLevel > 1 )
 		GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "Connected to the OpenVPN manage port (%1)." ).arg( QString().setNum( GlobalConfig->OpenvpnManagementPort ) ), GlobalConfig->debug );
 
+
+	socketReadyRead();
+
 }
 
 void OpenvpnManagementHandler::socketError( int e )
@@ -103,6 +110,19 @@ void OpenvpnManagementHandler::socketError( int e )
 		GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + QString().setNum( e ) , GlobalConfig->error );
 }
 
+void OpenvpnManagementHandler::greetingTimedOut()
+{
+	disconnect ( &greetingtimer, SIGNAL ( timeout() ), this, SLOT ( greetingTimedOut() ) );
+	greetingtimer.stop();
+
+	GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n("Got no greeting within %1 seconds from management interface, retrying.").arg("3"), GlobalConfig->error );
+
+
+	closeConnection();
+	usleep(500);
+	doConnect();
+}
+
 void OpenvpnManagementHandler::sendToServer( QString cmd )
 {
 	// write to the server
@@ -129,10 +149,10 @@ void OpenvpnManagementHandler::socketReadyRead()
 			if ( GlobalConfig->KvpncDebugLevel > 2 )
 				GlobalConfig->appendLogEntry( "OpenvpnManagementHandler raw: " + line, GlobalConfig->debug );
 
-			if ( line.find( "NOOP", 0, FALSE ) > -1 )
-			{
-				// NOOP
-			}
+// 			if ( line.find( "NOOP", 0, FALSE ) > -1 )
+// 			{
+// 				// NOOP
+// 			}
 			// 		else if ( line.find( ">HOLD:", 0, FALSE ) > -1 ) {
 			//
 			// 			if ( GlobalConfig->KvpncDebugLevel > 2 )
@@ -153,6 +173,17 @@ void OpenvpnManagementHandler::socketReadyRead()
 			// 			fInHold = false;
 			// 		}
 
+
+			if ( line.find( "INFO:OpenVPN Management Interface", 0, FALSE ) > -1 )
+			{
+				gotGreeting=true;
+				disconnect ( &greetingtimer, SIGNAL ( timeout() ), this, SLOT ( greetingTimedOut() ) );
+				greetingtimer.stop ();
+
+				if ( GlobalConfig->KvpncDebugLevel > 2 )
+					GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n("Got greeting from management interface."), GlobalConfig->debug );
+
+			}
 			else if ( line.find( "> NEED - OK:", 0, FALSE ) > -1 )
 			{
 
@@ -220,6 +251,7 @@ void OpenvpnManagementHandler::socketReadyRead()
 
 				if ( GlobalConfig->KvpncDebugLevel > 2 )
 					GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "Send username..." ), GlobalConfig->debug );
+				GlobalConfig->appendLogEntry( i18n( "Send username..." ), GlobalConfig->info );
 
 				if ( !GlobalConfig->currentProfile->getUserName().isEmpty()       /* && !GlobalConfig->currentProfile->getDontSaveUsername() */ )
 				{
@@ -270,6 +302,7 @@ void OpenvpnManagementHandler::socketReadyRead()
 
 				if ( GlobalConfig->KvpncDebugLevel > 2 )
 					GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "Send password..." ), GlobalConfig->debug );
+				GlobalConfig->appendLogEntry( i18n( "Send password..." ), GlobalConfig->info );
 
 				if ( !GlobalConfig->currentProfile->getUserPassword().isEmpty()       /* && GlobalConfig->currentProfile->getSaveUserPassword()  */ )
 				{
@@ -338,6 +371,7 @@ void OpenvpnManagementHandler::socketReadyRead()
 
 				if ( GlobalConfig->KvpncDebugLevel > 2 )
 					GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "Send HTTP Proxy username..." ), GlobalConfig->debug );
+				GlobalConfig->appendLogEntry( i18n( "Send HTTP Proxy username..." ), GlobalConfig->info );
 
 				if ( !GlobalConfig->currentProfile->getHttpProxyUser().isEmpty() )
 				{
@@ -356,6 +390,7 @@ void OpenvpnManagementHandler::socketReadyRead()
 
 				if ( GlobalConfig->KvpncDebugLevel > 2 )
 					GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "Send HTTP Proxy password..." ), GlobalConfig->debug );
+				GlobalConfig->appendLogEntry( i18n( "Send HTTP Proxy password..." ), GlobalConfig->info );
 
 				if ( !GlobalConfig->currentProfile->getHttpProxyPass().isEmpty() )
 				{
@@ -443,6 +478,7 @@ void OpenvpnManagementHandler::socketReadyRead()
 
 				if ( GlobalConfig->KvpncDebugLevel > 2 )
 					GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "Send private key password..." ), GlobalConfig->debug );
+				GlobalConfig->appendLogEntry( i18n( "Send private key password..." ), GlobalConfig->info );
 
 					sendToServer( "password  \"Private Key\" " + GlobalConfig->currentProfile->getPrivateKeyPass() + "\n" );
 				}
@@ -556,8 +592,7 @@ void OpenvpnManagementHandler::socketReadyRead()
 						// 												if ( GlobalConfig->KvpncDebugLevel > 5 )
 						// 				GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: private key password: " + GlobalConfig->TmpPrivateKeyPass, GlobalConfig->debug );
 
-						if ( GlobalConfig->KvpncDebugLevel > 2 )
-							GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "Send private key password..." ), GlobalConfig->debug );
+						GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "Send private key password..." ), GlobalConfig->info );
 
 						sendToServer( "password  \"Private Key\" " + GlobalConfig->TmpPrivateKeyPass + "\n" );
 					}
@@ -650,9 +685,10 @@ void OpenvpnManagementHandler::socketReadyRead()
 								// 												if ( GlobalConfig->KvpncDebugLevel > 5 )
 								// 				GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: token password: " + GlobalConfig->TmpPrivateKeyPass, GlobalConfig->debug );
 
-								if ( GlobalConfig->KvpncDebugLevel > 1 )
-									GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "Send token password..." ), GlobalConfig->debug );
 
+								if ( GlobalConfig->KvpncDebugLevel > 2 )
+									GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "Send token password..." ), GlobalConfig->debug );
+								GlobalConfig->appendLogEntry( i18n( "Send token password..." ), GlobalConfig->info );
 								sendToServer( "password  \"eToken token\" " + GlobalConfig->TmpPrivateKeyPass + "\n" );
 							}
 							else
@@ -670,11 +706,16 @@ void OpenvpnManagementHandler::socketReadyRead()
 
 			else if ( line.find( "SUCCESS: 'eToken token' password entered, but not yet verified", 0, FALSE ) > -1 )
 			{
-
 				if ( GlobalConfig->KvpncDebugLevel > 1 )
 					GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "got %1 message" ).arg("SUCCESS for 'eToken token' password"), GlobalConfig->debug );
 			}
 
+			else if ( line.find( "SUCCESS: 'Auth' password entered, but not yet verified", 0, FALSE ) > -1 )
+			{
+				if ( GlobalConfig->KvpncDebugLevel > 1 )
+					GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "got %1 message" ).arg("SUCCESS for user password"), GlobalConfig->debug );
+			}
+
 			else if ( line.find( "Need 'token-insertion-request'", 0, FALSE ) > -1 )
 			{
 // 				if ( GlobalConfig->KvpncDebugLevel > 1 )
@@ -682,12 +723,14 @@ void OpenvpnManagementHandler::socketReadyRead()
 				KMessageBox::error ( 0, i18n("Token \"%1\" is not inserted!").arg(GlobalConfig->currentProfile->getPkcs11Id()), i18n("Token missing") );
 				abort = true;
 			}
+
 			else if ( line.find( "SUCCESS: 'Private Key' password entered, but not yet verified", 0, FALSE ) > -1 )
 			{
 
 				if ( GlobalConfig->KvpncDebugLevel > 1 )
 					GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "got %1 message" ).arg("SUCCESS for 'Private Key' password"), GlobalConfig->debug );
 			}
+
 			else
 			{
 				if ( GlobalConfig->KvpncDebugLevel > 1 )
@@ -726,8 +769,6 @@ bool OpenvpnManagementHandler::doConnect()
 	socket = new QSocket( this );
 	connect( socket, SIGNAL( connected() ), this, SLOT( socketConnected() ) );
 	connect( socket, SIGNAL( hostFound() ), this, SLOT( hostFound() ) );
-	connect( socket, SIGNAL( connectionClosed() ), this, SLOT( socketConnectionClosed() ) );
-	connect( socket, SIGNAL( readyRead() ), this, SLOT( socketReadyRead() ) );
 	connect( socket, SIGNAL( error( int ) ), this, SLOT( socketError( int ) ) );
 
 	if ( GlobalConfig->KvpncDebugLevel > 1 )
@@ -750,6 +791,13 @@ bool OpenvpnManagementHandler::doConnect()
 // 	}
 
 // 	return false;
+
+	connect ( &greetingtimer, SIGNAL ( timeout() ), this, SLOT ( greetingTimedOut() ) );
+	greetingtimer.start ( 3 * 1000, TRUE );
+
+	if ( GlobalConfig->KvpncDebugLevel > 2 )
+		GlobalConfig->appendLogEntry( "OpenvpnManagementHandler " + i18n("Management greeting timer started."), GlobalConfig->debug );
+
 	return true;
 }
 
@@ -760,4 +808,5 @@ void OpenvpnManagementHandler::hostFound()
 	{
 		GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "Connecting to the OpenVPN manage port (%1)... host found" ).arg( QString().setNum( GlobalConfig->OpenvpnManagementPort ) ), GlobalConfig->debug );
 	}
+
 }
