@@ -22,6 +22,7 @@
 
 #include <stdlib.h>
 #include <qsocket.h>
+#include <qtimer.h>
 #include "kvpncconfig.h"
 
 
@@ -38,6 +39,7 @@ class OpenvpnManagementHandler : public QObject {
 		void closeConnection();
 		bool isConnectedToManagementPort();
 		bool doConnect();
+		QTimer greetingtimer;
 
 	protected slots:
 		void socketConnected();
@@ -46,6 +48,7 @@ class OpenvpnManagementHandler : public QObject {
 		void socketReadyRead();
 		void socketClosed();
 		void hostFound();
+		void greetingTimedOut();
 
 	public slots:
 		void sendToServer(QString cmd);
@@ -53,6 +56,7 @@ class OpenvpnManagementHandler : public QObject {
 	private:
 		KVpncConfig *GlobalConfig;
 		bool fInHold;
+		bool gotGreeting;
 		bool connectedToManagementPort;
 		QSocket *socket;
 		QString errormsg;
