@@ -25,6 +25,19 @@
 #
 ##############################################################
 
+if [ $# -ne 5 ]; then
+echo "help:"
+echo "-----"
+echo "PING <path to ping>"
+echo "PINGHOST <ip | hostname>"
+echo "INTERVAL <val>"
+echo "TEST_PING_COUNT <val>"
+echo "QUIET [0|1]"
+echo ""
+echo "parameters count: $#"
+exit 1
+fi
+
 PING=$1
 PINGHOST=$2
 INTERVAL=$3
