@@ -23,6 +23,7 @@
 #include <kdialogbase.h>
 
 #include <qptrlist.h>
+#include <qstringlist.h>
 #include <qtextedit.h>
 #include <qcolor.h>
 #include <qscrollview.h>
@@ -53,6 +54,7 @@
 #include "profileopenvpnoptions.h"
 #include "profilepptpoptions.h"
 #include "profileracoonoptions.h"
+#include "profilevtunoptions.h"
 #include "profileuseroptions.h"
 
 
@@ -78,6 +80,7 @@ public:
 
 public slots:
 	void accept();
+	void reject();
 	void slotApply();
 	void authTypeChanged( int authtype );
 	void connectionTypeChanged( int connectiontype );
@@ -91,6 +94,10 @@ public slots:
 	void userAuthToggled(bool);
 	void useUdpToggled(bool);
 	void useSpecialServerSmartcardificateToggled(bool);
+	void applicationVersionToggled(bool);
+	void IkeGroupToggled(bool);
+	void perfectForwardSecurityToggled(bool);
+	void singleDesToggled(bool);
 
 private slots:
 	void OpenvpnPathChanged(const QString&);
@@ -99,14 +106,18 @@ private slots:
 	void PptpPathChanged(const QString&);
 	void RacoonPathChanged(const QString&);
 	void VpncPathChanged(const QString&);
+	void CiscoVpncPathChanged(const QString&);
 	void L2tpdPathChanged(const QString&);
-	
+	void Xl2tpdPathChanged(const QString&);
+	void VtundPathChanged(const QString&);
+
 	void lineeditTextChanged(const QString &);
 	void checkboxStateChanged(int);
 	void showEvent(QShowEvent* e);
 	void detectPkcs11Ids();
 	void detectPkcs11Slots();
 	void localPortToggled(bool);
+	void tunnelDeviceTypeChanged(const QString &);
 
 
 protected:
@@ -118,9 +129,11 @@ protected:
 	QString lastProfileName;
 	int KvpncDebugLevel;
 	bool canAccept;
+	bool configChanged;
 	QPixmap ok_icon;
 	QPixmap wrong_icon;
 	QScrollView* DaemonScrollView;
+	QStringList CiscoCerts;
 
 public:
 	QApplication *app;
@@ -151,6 +164,7 @@ public:
 	ProfilePptpOptions *ProfilePptpOptionsWidget;
 	ProfileRacoonOptions *ProfileRacoonOptionsWidget;
 	ProfileCiscoOptions *ProfileCiscoOptionsWidget;
+	ProfileVtunOptions *ProfileVtunOptionsWidget;
 	ProfileCmdExecBeforeConnectOptions *ProfileCmdExecBeforeConnectOptionsWidget;
 	ProfileCmdExecBeforeDisconnectOptions *ProfileCmdExecBeforeDisconnectOptionsWidget;
 	ProfileCmdExecAfterConnectOptions *ProfileCmdExecAfterConnectOptionsWidget;
@@ -171,6 +185,7 @@ public:
 	QComboBox *ProfilePptpSelector;
 	QComboBox *ProfileRacoonSelector;
 	QComboBox *ProfileCiscoSelector;
+	QComboBox *ProfileVtunSelector;
 	QComboBox *ProfileCmdExecBeforeConnectSelector;
 	QComboBox *ProfileCmdExecBeforeDisconnectSelector;
 	QComboBox *ProfileCmdExecAfterConnectSelector;
@@ -179,6 +194,7 @@ public:
 	QFrame* DaemonFrame;
 
 	bool profileAddedOrDeleted;
+	bool profileHasChanged;
 	bool showOnlyProfiles;
 	QString NewProfileName;
 
