@@ -35,9 +35,9 @@ public:
 	~ProfileGeneralOptions();
 
 public slots:
-    void advancedSettingsClicked();
     void useReconnectAfterDisconnectToggled(bool);
     void useReconnectDelayToggled(bool);
+	void UseDnsUpdateToggled(bool);
 
 protected:
 	KVpncConfig *GlobalConfig;
