@@ -128,14 +128,10 @@ void ProfileOpenvpnOptions::authenticateWithUsernameAndPasswordToggled(bool)
 		UseOnlyCaCertAndUserAuthCheckBox->setEnabled(false);
 }
 
-
-
-
-
-
-
-
-
-
-
-
+void ProfileOpenvpnOptions::useAuthenticationAlgorithmToggled(bool)
+{
+	if (UseAuthenticationAlgorithmCheckBox->isChecked())
+		UserdefiniedDigestComboBox->setEnabled(true);
+	else
+		UserdefiniedDigestComboBox->setEnabled(false);
+}
