@@ -40,9 +40,10 @@ void ProfilePptpOptions::useDnsServerToggled(bool)
 }
 
 
-
-
-
-
-
-
+void ProfilePptpOptions::useSearchDomainInResolvConfToggled(bool)
+{
+	if ( UseSearchDomainInResolvConfCheckbox ->isChecked() )
+		SearchDomainInResolvConfLineedit->setEnabled( true );
+	else
+		SearchDomainInResolvConfLineedit->setEnabled( false );
+}
