@@ -20,7 +20,9 @@
 #include "profileracoonoptions.h"
 
 #include <klineedit.h>
+#include <kcombobox.h>
 #include <qcheckbox.h>
+#include <qlabel.h>
 
 ProfileRacoonOptions::ProfileRacoonOptions(QWidget *parent)
 		: ProfileRacoonOptionsBase(parent)
@@ -47,5 +49,16 @@ void ProfileRacoonOptions::useLeftNextHopToggled(bool)
 }
 
 
-
-
+void ProfileRacoonOptions::localIDTypeToggled(const QString& text)
+{
+	if (text == "asn1dn")
+	{
+		LocalIDLineEdit->setDisabled(true);
+		LocalIDLabel->setDisabled(true);
+	}
+	else
+	{
+		LocalIDLineEdit->setDisabled(false);
+		LocalIDLabel->setDisabled(false);
+	}
+}
