@@ -43,6 +43,9 @@ ToolInfo::ToolInfo( const QString &Name)
 
 	Version=i18n("No info");
 
+	env = new QStringList();
+	*env << "LC_ALL=C" << "LANG=C" << "PATH=/bin:/usr/bin:/usr/sbin:/sbin";
+
 	collectRunning=false;
 	collectOpenvpnCapabilitiesRunning=false;
 	collectToolInfo();
@@ -109,6 +112,7 @@ bool ToolInfo::collectToolInfo()
 		CollectToolInfoProcess->addArgument(PathToExec);
 		if (Name == "vpnc")
 			CollectToolInfoProcess->addArgument("--version");
+		else if (Name == "vpnclient") { }
 		else	if (Name == "ipsec")
 			CollectToolInfoProcess->addArgument("--version");
 		else	if (Name == "racoon")
@@ -149,8 +153,14 @@ bool ToolInfo::collectToolInfo()
 			;
 		else	if (Name == "l2tpd")
 			CollectToolInfoProcess->addArgument("-D");
+		else	if (Name == "xl2tpd")
+			CollectToolInfoProcess->addArgument("-v");
 		else if (Name =="pkcs11-tool")
 			CollectToolInfoProcess->addArgument("-I");
+		else if (Name =="vtund")
+			CollectToolInfoProcess->addArgument("-h");
+		else if (Name == "cisco_cert_mgr")
+			;
 		else
 		{
 // 			if (GlobalConfig->KvpncDebugLevel > 2)
@@ -164,9 +174,9 @@ bool ToolInfo::collectToolInfo()
 		if (run )
 		{
 
-			if ( !PathToExec.isEmpty() && !CollectToolInfoProcess->start() )
+			if ( !PathToExec.isEmpty() && !CollectToolInfoProcess->start(env) )
 			{
-				std::cerr << i18n("Unable to start collectToolInfo process (%1)!").arg(Name) << std::endl;
+				std::cerr << (i18n("Unable to start collectToolInfo process (%1)!").arg(Name)).ascii() << std::endl;
 				//delete CollectToolInfoProcess;
 				collectRunning=false;
 				success=false;
@@ -177,7 +187,7 @@ bool ToolInfo::collectToolInfo()
 
 				while(CollectToolInfoProcess->isRunning() && collectRunning)
 				{
-					if (Name == "l2tpd" || Name == "pkcs11-tool") 
+					if (Name == "l2tpd" || Name == "pkcs11-tool" || Name == "cisco_cert_mgr"  || Name == "vpnclient")
 					{
 						usleep(500);
 						CollectToolInfoProcess->kill();
@@ -228,6 +238,11 @@ void ToolInfo::readStdOutCollectToolInfo()
 				Version = msg.simplifyWhiteSpace().section(' ',2,2);
 			}
 		}
+		else if (Name == "vpnclient" || Name =="cisco_cert_mgr")
+		{
+			if ( msg.find( "Cisco Systems VPN Client", 0, FALSE ) > -1 )
+				Version = msg.section(' ',5,6); // "Cisco Systems VPN Client Version 4.8.00 (0490)"
+		}
 		else	if (Name == "ipsec")
 		{
 			if ( msg.find( "wan", 0, FALSE ) > -1 )
@@ -332,6 +347,22 @@ void ToolInfo::readStdOutCollectToolInfo()
 				CollectToolInfoProcess->kill();
 			}
 		}
+		else	if (Name == "xl2tpd")
+		{
+			if ( msg.find( "version:", 0, FALSE ) > -1 )
+			{
+// 				std::cout << "stdout collectToolInfo: " << msg << std::endl;
+				Version = msg.section(' ',3,3).stripWhiteSpace();
+			}
+		}
+		else	if (Name == "vtund")
+		{
+			if ( msg.find( "VTun ver", 0, FALSE ) > -1 )
+			{
+// 				std::cout << "stdout collectToolInfo: " << msg << std::endl;
+				Version = msg.section(' ',2,3).stripWhiteSpace();
+			}
+		}
 		else
 		{
 			KMessageBox::information(0,QString("Name: "+Name+", Path: "+PathToExec+", Version: "+Version+", err: "+msg),"aaa");
@@ -472,7 +503,6 @@ void ToolInfo::removeSearchPath(const QString& path )
 		return;
 }
 
-
 void ToolInfo::getOpenvpnCapabilities()
 {
 
@@ -492,9 +522,9 @@ void ToolInfo::getOpenvpnCapabilities()
 
 		collectOpenvpnCapabilitiesRunning=false;
 
-		if ( !PathToExec.isEmpty() && !CollectOpenvpnCapabilitiesProcess->start() )
+		if ( !PathToExec.isEmpty() && !CollectOpenvpnCapabilitiesProcess->start(env) )
 		{
-			std::cerr << i18n("Unable to start collectToolInfo process (%1)!").arg(Name) << std::endl;
+			std::cerr << i18n("Unable to start collectToolInfo process (%1)!").arg(Name).ascii() << std::endl;
 
 			//delete CollectToolInfoProcess;
 			collectOpenvpnCapabilitiesRunning=false;
