@@ -39,14 +39,16 @@
 //END INCLUDES
 
 Utils::Utils( KVpncConfig* config, QObject *parent, const char *name )
-		: QObject( parent, name ) {
+		: QObject( parent, name )
+{
 	env = new QStringList();
-	*env << "LC_ALL=C" << "LANG=C";
+	*env << "LC_ALL=C" << "LANG=C" << "PATH=/bin:/usr/bin:/usr/sbin:/sbin";
 	this->config = config;
 	retrieveValidNetworkdevice = false;
 }
 
-Utils::~Utils() {
+Utils::~Utils()
+{
 	// 	if(createProcess!=0)
 	// 		delete createProcess;
 	//
@@ -54,7 +56,8 @@ Utils::~Utils() {
 	// 		delete NetworkDeviceTestProcess;
 }
 
-bool Utils::isValidIPv4Address( QString Address ) {
+bool Utils::isValidIPv4Address( QString Address )
+{
 	if ( Address.contains( '.' ) != 3 )
 		return false;
 	else {
@@ -77,7 +80,8 @@ bool Utils::isValidIPv4Address( QString Address ) {
 	}
 }
 
-bool Utils::isValidIPv4NetworkAddress( QString Address ) {
+bool Utils::isValidIPv4NetworkAddress( QString Address )
+{
 	if ( isValidIPv4Address( Address ) ) {
 		if ( Address.section( '.', 3, 3 ).toInt() == 0 )
 			return true;
@@ -87,7 +91,8 @@ bool Utils::isValidIPv4NetworkAddress( QString Address ) {
 		return false;
 }
 
-bool Utils::isValidIPv4BroadcastAddress( QString Address ) {
+bool Utils::isValidIPv4BroadcastAddress( QString Address )
+{
 	if ( isValidIPv4Address( Address ) ) {
 		if ( Address.section( '.', 3, 3 ).toInt() == 255 )
 			return true;
@@ -98,14 +103,40 @@ bool Utils::isValidIPv4BroadcastAddress( QString Address ) {
 	return false;
 }
 
-bool Utils::tunDevExists() {
+bool Utils::isValidIPv4Netmask(QString Netmask)
+{
+	if ( Netmask.contains( '.' ) != 3 )
+		return false;
+	else {
+		//std::cout << "test1 succeed.\n";
+		QString addr = Netmask;
+		int part0 = addr.section( '.', 0, 0 ).toInt();
+		int part1 = addr.section( '.', 1, 1 ).toInt();
+		int part2 = addr.section( '.', 2, 2 ).toInt();
+		int part3 = addr.section( '.', 3, 3 ).toInt();
+
+		//std::cout << "part0 " << part0 << ", part1 " << part1 <<  ", part2 " << part2 << ", part3 " << part3 << "\n";
+
+		if ( ( part0 > 254 && part0 <= 255 ) &&
+		        ( part1 > 254 && part1 <= 255 ) &&
+		        ( part2 >= 0 && part2 <= 255 ) &&
+		        ( part3 >= 0 && part3 <= 253 ) )
+			return true;
+		else
+			return false;
+	}
+}
+
+bool Utils::tunDevExists()
+{
 	if ( QFile ( "/dev/net/tun" ).exists() )
 		return true;
 	else
 		return false;
 }
 
-bool Utils::createTunDev() {
+bool Utils::createTunDev()
+{
 	createProcess = new QProcess( this );
 	connect( createProcess, SIGNAL( readyReadStdout() ), this, SLOT( readStdOutCreateTunDev() ) );
 	connect( createProcess, SIGNAL( readyReadStderr() ), this, SLOT( readStdErrCreateTunDev() ) );
@@ -117,7 +148,7 @@ bool Utils::createTunDev() {
 		createProcess->addArgument( "/dev/net" );
 
 
-		if ( !createProcess->start() ) {
+		if ( !createProcess->start(env) ) {
 			kdError() << "Unable to create tunnel device file!" << endl;
 			return false;
 		} else {
@@ -135,7 +166,7 @@ bool Utils::createTunDev() {
 	createProcess->addArgument( "10" );
 	createProcess->addArgument( "200" );
 
-	if ( !createProcess->start() ) {
+	if ( !createProcess->start(env) ) {
 		kdError() << "Unable to create tunnel device file!" << endl;
 		return false;
 	} else
@@ -144,7 +175,8 @@ bool Utils::createTunDev() {
 	return false;
 }
 
-bool Utils::loadKernelModule( QString Name, QApplication *app ) {
+bool Utils::loadKernelModule( QString Name, QApplication *app )
+{
 	if ( !Name.isEmpty() ) {
 		modprobeSuccess = true;
 		ModprobeProcess = new QProcess( this );
@@ -166,13 +198,14 @@ bool Utils::loadKernelModule( QString Name, QApplication *app ) {
 		return false;
 }
 
-bool Utils::doChmod( QString file, QString mode ) {
+bool Utils::doChmod( QString file, QString mode )
+{
 	QProcess * chmodProcess = new QProcess( this );
 	chmodProcess->addArgument( "chmod" );
 	chmodProcess->addArgument( mode );
 	chmodProcess->addArgument( file );
 
-	if ( !chmodProcess->start() ) {
+	if ( !chmodProcess->start(env) ) {
 		// KMessageBox::sorry( this, i18n( "\"%1\" start failed!" ).arg( "PppdUpScript" ) );
 		config->appendLogEntry( i18n( "Chmod of %1 failed!" ).arg( file ), config->error );
 		return false;
@@ -186,17 +219,30 @@ bool Utils::doChmod( QString file, QString mode ) {
 	}
 }
 
-QPtrList<ToolInfo>* Utils::getToolList() {
+bool Utils::resolvConfAvailable()
+{
+	bool resolvConfAvailable=false;
+	if (QFile("/sbin/resolvconf").exists() && QFile("/etc/init.d/resolvconf").exists())
+		resolvConfAvailable=true;
+	else
+		resolvConfAvailable=false;
+	return resolvConfAvailable;
+}
+
+QPtrList<ToolInfo>* Utils::getToolList()
+{
 	QPtrList<ToolInfo> *ToolList = new QPtrList<ToolInfo>();
 
 	//TODO move to KVpncConfig
 	QStringList *ToolNamesList = new QStringList();
 	ToolNamesList->append( "vpnc" );
+	ToolNamesList->append( "vpnclient" );
 	ToolNamesList->append( "racoon" );
 	ToolNamesList->append( "ipsec" ); // freeswan
 	ToolNamesList->append( "pppd" );
 	ToolNamesList->append( "pptp" );
 	ToolNamesList->append( "l2tpd" );
+	ToolNamesList->append( "xl2tpd" );
 	ToolNamesList->append( "setkey" );
 	ToolNamesList->append( "iptables" );
 	ToolNamesList->append( "openssl" );
@@ -208,6 +254,9 @@ QPtrList<ToolInfo>* Utils::getToolList() {
 	ToolNamesList->append( "ifconfig" );
 	ToolNamesList->append( "route" );
 	ToolNamesList->append( "pkcs11-tool" );
+	ToolNamesList->append( "bash" );
+	ToolNamesList->append( "vtund" );
+	ToolNamesList->append( "cisco_cert_mgr" );
 
 	ToolInfo *currentTool;
 	for ( QStringList::Iterator it = ToolNamesList->begin(); it != ToolNamesList->end(); it++ ) {
@@ -217,6 +266,8 @@ QPtrList<ToolInfo>* Utils::getToolList() {
 		currentTool->programsInPath =config->programsInPath;
 		if ( currentTool->Name == "vpnc" )
 			currentTool->TryPath_first = config->pathToVpnc;
+		else if (currentTool->Name == "vpnclient")
+			currentTool->TryPath_first = config->pathToCiscoVpnc;
 		else	if ( currentTool->Name == "ipsec" )
 			currentTool->TryPath_first = config->pathToFreeswan;
 		else	if ( currentTool->Name == "racoon" )
@@ -249,6 +300,12 @@ QPtrList<ToolInfo>* Utils::getToolList() {
 			currentTool->TryPath_first = config->pathToL2tpd;
 		else	if ( currentTool->Name == "pkcs11-tool" )
 			currentTool->TryPath_first = config->pathToPkcs11Tool;
+		else	if ( currentTool->Name == "bash" )
+			currentTool->TryPath_first = config->InterpreterShell;
+		else	if ( currentTool->Name == "vtund" )
+			currentTool->TryPath_first = config->pathToVtund;
+		else if ( currentTool->Name == "cisco_cert_mgr" )
+			currentTool->TryPath_first = config->pathToCiscoCertMgr;
 
 		ToolList->append( currentTool );
 		currentTool->collectToolInfo();
@@ -263,7 +320,8 @@ QPtrList<ToolInfo>* Utils::getToolList() {
 
 }
 
-ToolInfo* Utils::getToolInfo( KVpncConfig *GlobalConfig, QString name ) {
+ToolInfo* Utils::getToolInfo( KVpncConfig *GlobalConfig, QString name )
+{
 	ToolInfo * Tool = 0;
 	for ( Tool = GlobalConfig->ToolList->first();Tool;Tool = GlobalConfig->ToolList->next() ) {
 		if ( Tool->Name == name )
@@ -272,7 +330,8 @@ ToolInfo* Utils::getToolInfo( KVpncConfig *GlobalConfig, QString name ) {
 	return Tool;
 }
 
-QString Utils::resolveName( QString Name ) {
+QString Utils::resolveName( QString Name )
+{
 	resolvedIP = "";
 	resolveFinished = false;
 
@@ -286,7 +345,8 @@ QString Utils::resolveName( QString Name ) {
 	return resolvedIP;
 }
 
-QString Utils::removeSpecialCharsForFilename( QString filename ) {
+QString Utils::removeSpecialCharsForFilename( QString filename )
+{
 	filename.replace( QRegExp( "[*]+" ), "_" );
 	filename.replace( QRegExp( "[+] +" ), "_" );
 	filename.replace( QRegExp( "[$]+" ), "_" );
@@ -298,15 +358,19 @@ QString Utils::removeSpecialCharsForFilename( QString filename ) {
 	filename.replace( QRegExp( "ï¿œ" ), "_" );
 	filename.replace( QRegExp( "ï¿œ" ), "_" );
 	filename.replace( QRegExp( "ï¿œ" ), "_" );
-	filename.replace( QRegExp( "\\+" ), "_" );
-	filename.replace( QRegExp( "/+" ), "_" );
+	filename.replace( "\\" , "_" );
+	filename.replace( "/" , "_" );
 	filename.replace( QRegExp( ";+" ), "_" );
 	filename.replace( QRegExp( " " ), "_" );
 	filename.replace( QRegExp( "_+" ), "_" );
+	filename.replace(  ")" , "_" );
+	filename.replace(  "(" , "_" );
+	filename.replace(  " " , "_" );
 	return filename;
 }
 
-QStringList Utils::getOpenvpnCiphers() {
+QStringList Utils::getOpenvpnCiphers()
+{
 	OpenvpnCiphers.clear();
 	retrieveOpenvpnCiphers = false;
 
@@ -338,7 +402,8 @@ QStringList Utils::getOpenvpnCiphers() {
 	return OpenvpnCiphers;
 }
 
-QStringList Utils::getOpenvpnDigests() {
+QStringList Utils::getOpenvpnDigests()
+{
 	OpenvpnDigests.clear();
 	retrieveOpenvpnDigests = false;
 	OpenvpnDigestCount=0;
@@ -376,7 +441,8 @@ QStringList Utils::getOpenvpnDigests() {
 	return OpenvpnDigests;
 }
 
-QStringList Utils::getKernelCrypto() {
+QStringList Utils::getKernelCrypto()
+{
 	KernelCrypto.clear();
 	QFile cryptoprocfile( "/proc/crypto" );
 
@@ -384,7 +450,7 @@ QStringList Utils::getKernelCrypto() {
 		QTextStream stream( &cryptoprocfile );
 		QString line;
 		if (config->KvpncDebugLevel > 2)
-			std::cout << "Kernel crypto list: " << std::endl;
+//		std::cout << "Kernel crypto list: " << std::endl;
 		while ( !stream.atEnd() ) {
 			line = stream.readLine();
 			if (line.find("name") > -1 )
@@ -400,7 +466,8 @@ QStringList Utils::getKernelCrypto() {
 	return KernelCrypto;
 }
 
-QString Utils::getNameAndPidOfProgramListen( int port ) {
+QString Utils::getNameAndPidOfProgramListen( int port )
+{
 	if ( port == 0 )
 		return "";
 
@@ -553,6 +620,55 @@ QStringList Utils::getSmartcardCertsFromSlot(QString slot,QString IdType,QString
 	return SmartcardCertsFromSlot;
 }
 
+QStringList Utils::getCertsFromCiscoCertStore(QString type)
+{
+
+	if (type != "user" && type != "ca" && type != "enrollment")
+		type="user";
+
+	if (config->KvpncDebugLevel > 2)
+		config->appendLogEntry("getCertsFromCiscoCertStore: "+i18n("type: %1").arg(type),config->debug );
+
+	CertsFromCiscoCertStore.clear();
+	CertsFromCiscoCertPos=0;
+	
+	if ( config->pathToCiscoCertMgr.isEmpty() )
+		return CertsFromCiscoCertStore;
+
+	GetCertsFromCiscoCertStoreProcess = new QProcess( this );
+	GetCertsFromCiscoCertStoreProcess->setCommunication( QProcess::Stdin | QProcess::Stdout | QProcess::Stderr | QProcess::DupStderr );
+	GetCertsFromCiscoCertStoreProcess->addArgument( config->pathToCiscoCertMgr );
+
+	if (type == "user")
+		GetCertsFromCiscoCertStoreProcess->addArgument( "-U");
+	if (type == "ca")
+		GetCertsFromCiscoCertStoreProcess->addArgument( "-R");
+	GetCertsFromCiscoCertStoreProcess->addArgument( "-op");
+	if (type == "enrollent")
+		GetCertsFromCiscoCertStoreProcess->addArgument( "-E");
+	GetCertsFromCiscoCertStoreProcess->addArgument( "-op");
+
+
+	GetCertsFromCiscoCertStoreProcess->addArgument( "list");
+	
+	connect( GetCertsFromCiscoCertStoreProcess, SIGNAL( readyReadStdout() ), this, SLOT( readOutGetCertsFromCiscoCertStoreSlot() ) );
+	
+	if ( !GetCertsFromCiscoCertStoreProcess->start( env ) ) {
+		kdError() << "Unable to fetch certificates via cisco_cert_mgr!" << endl;
+		return false;
+	} else {
+
+		while ( GetCertsFromCiscoCertStoreProcess->isRunning() )
+// 			usleep(500);
+			config->appPointer->processEvents();
+
+		disconnect( GetCertsFromCiscoCertStoreProcess, SIGNAL( readyReadStdout() ), this, SLOT( readOutGetCertsFromCiscoCertStoreSlot() ) );
+
+	}
+
+	return CertsFromCiscoCertStore;
+}
+
 bool Utils::getNeedsPassphrase(QString key)
 {
 	
@@ -605,18 +721,21 @@ void Utils::readStdOutCreateTunDev() {
 	kdDebug() << "readStdOutCreateTunDev(): " << msg << endl;
 }
 
-void Utils::readStdErrCreateTunDev() {
+void Utils::readStdErrCreateTunDev()
+{
 	QString msg = QString( createProcess->readStderr() );
 	kdError() << "readStdErrCreateTunDev" << msg << endl;
 
 }
 
-void Utils::readStdOutLoadKernelModule() {
+void Utils::readStdOutLoadKernelModule()
+{
 	QString msg = QString( ModprobeProcess->readStdout() );
 	kdDebug() << "readStdErrreadStdOutLoadKernelModule" << msg << endl;
 }
 
-void Utils::readStdErrLoadKernelModule() {
+void Utils::readStdErrLoadKernelModule()
+{
 	QString msg = QString( ModprobeProcess->readStderr() );
 	// 	kdDebug() << "readStdErrreadStderrLoadKernelModule" << msg << endl;
 
@@ -634,11 +753,16 @@ void Utils::readStdErrLoadKernelModule() {
 	}
 }
 
-void Utils::readStdOutToolsTest() {}
+void Utils::readStdOutToolsTest()
+{
+}
 
-void Utils::readStdErrToolsTest() {}
+void Utils::readStdErrToolsTest()
+{
+}
 
-void Utils::readStdOutRetriveOpenvpnCiphers() {
+void Utils::readStdOutRetriveOpenvpnCiphers()
+{
 	while ( OpenvpnCiphersProcess->canReadLineStdout() ) {
 		QString msg = QString( OpenvpnCiphersProcess->readLineStdout() );
 		if ( msg.contains( "default key" ) ) {
@@ -648,14 +772,16 @@ void Utils::readStdOutRetriveOpenvpnCiphers() {
 	}
 }
 
-void Utils::readStdErrRetriveOpenvpnCiphers() {
+void Utils::readStdErrRetriveOpenvpnCiphers()
+{
 	while ( OpenvpnCiphersProcess->canReadLineStderr() ) {
 		QString msg = QString( OpenvpnCiphersProcess->readLineStderr() );
 
 	}
 }
 
-void Utils::readStdOutRetriveOpenvpnDigests() {
+void Utils::readStdOutRetriveOpenvpnDigests()
+{
 	while ( OpenvpnDigestProcess->canReadLineStdout() ) {
 		QString msg = QString( OpenvpnDigestProcess->readLineStdout() );
 		OpenvpnDigestCount+=1;
@@ -666,24 +792,30 @@ void Utils::readStdOutRetriveOpenvpnDigests() {
 	}
 }
 
-void Utils::readStdErrRetriveOpenvpnDigests() {
+void Utils::readStdErrRetriveOpenvpnDigests()
+{
 	while ( OpenvpnDigestProcess->canReadLineStderr() ) {
 		QString msg = QString( OpenvpnDigestProcess->readLineStderr() );
 
 	}
 }
 
-void Utils::readStdOutGetNameAndPidOfProgramListen() {
+void Utils::readStdOutGetNameAndPidOfProgramListen()
+{
 	while ( NameAndPidOfProgramListenProcess->canReadLineStdout() ) {
 		QString msg = QString( NameAndPidOfProgramListenProcess->readLineStdout() );
-		if ( msg.contains( "/" ) and msg.contains( QString().setNum( ListenPort ) ) ) {
+		if ( msg.contains( "/" ) && msg.contains( QString().setNum( ListenPort ) ) && msg.simplifyWhiteSpace().section( ' ', 3, 3 ).section(':',1,1) == QString().setNum( ListenPort )  ) {
 			std::cout << msg.ascii() << std::endl;
 			NameAndPidOfProgramListen = ( msg.simplifyWhiteSpace().section( ' ', 5, 5 ) );
+			if (NameAndPidOfProgramListen.contains( "LISTEN"))
+				NameAndPidOfProgramListen = ( msg.simplifyWhiteSpace().section( ' ', 6, 6 ) );
+			break;
 		}
 	}
 }
 
-void Utils::readStdErrGetNameAndPidOfProgramListen() {
+void Utils::readStdErrGetNameAndPidOfProgramListen()
+{
 	while ( NameAndPidOfProgramListenProcess->canReadLineStderr() ) {
 		QString msg = QString( NameAndPidOfProgramListenProcess->readLineStderr() );
 
@@ -779,6 +911,65 @@ void Utils::readOutGetSmartcardCertsFromSlot()
 
 }
 
+void Utils::readOutGetCertsFromCiscoCertStoreSlot()
+{
+	while ( GetCertsFromCiscoCertStoreProcess->canReadLineStdout() ) {
+		QString msg = QString( GetCertsFromCiscoCertStoreProcess->readLineStdout() );
+
+// samle output :(
+
+// Cisco Systems VPN Client Version 4.8.00 (0490)
+// Copyright (C) 1998-2005 Cisco Systems, Inc. All Rights Reserved.
+// Client Type(s): Linux
+// Running on: Linux 2.6.22-2-686 #1 SMP Fri Aug 31 00:24:01 UTC 2007 i686
+// 
+// 
+//       Cert #          Common Name
+//       -------         ------------
+// 
+//       0               crissi 
+
+		if (config->KvpncDebugLevel > 2)
+			std::cout << "readOutGetCertsFromCiscoCertStoreSlot: " << msg << std::endl;
+
+		if (msg.find("Cert #",0,FALSE) > -1)
+			CertsFromCiscoCertPos=1;
+		if (CertsFromCiscoCertPos==1 || CertsFromCiscoCertPos ==2 | CertsFromCiscoCertPos ==3)
+		{
+			CertsFromCiscoCertPos++;
+			continue;
+		}
+		else if (CertsFromCiscoCertPos>=4)
+		{
+			if (msg.length() > 2)
+			{
+	// 			"       0               crissi "
+				int idx=0; // first non space => 0
+				int idx2=0; // second nonspace => c
+				for (idx=0;idx<(int)msg.length();idx++)
+					if (!msg.at(idx).isSpace())
+						break;
+
+				if (config->KvpncDebugLevel > 2)
+					std::cout << "readOutGetCertsFromCiscoCertStoreSlot: idx " << idx << std::endl;
+
+				for (idx2=idx+1;idx2<(int)msg.length();idx2++)
+					if (!msg.at(idx2).isSpace())
+						break;
+				if (config->KvpncDebugLevel > 2)
+					std::cout << "readOutGetCertsFromCiscoCertStoreSlot: idx2 " << idx2 << std::endl;
+				QString common_name = msg.right(msg.length()-idx2);
+				if (common_name.length() > 0)
+				{
+					if (config->KvpncDebugLevel > 2)
+						std::cout << "readOutGetCertsFromCiscoCertStoreSlot => cert " << common_name << std::endl;
+					CertsFromCiscoCertStore.append( common_name );
+				}
+			}
+		}
+	}
+}
+
 void Utils::readOutNeedsPassphrase()
 {
 	while ( NeedsPassphraseProcess->canReadLineStdout() ) {
