@@ -54,6 +54,8 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	AuthType="";
 	pingHostIP="";
 	SpecialRemoteID="";
+	SpecialLocalID="";
+	LocalIDType="asn1dn";
 	LocalVirtualIP="";
 	RemoteVirtualIP="";
 	PreSharedKeyFile="";
@@ -66,6 +68,12 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	LeftNextHop="";
 	AuthMethod="chap";
 	TunnelDeviceType="tun";
+	SearchDomainInResolvConf="";
+	AuthenticationDirection="none";
+	CiscoNatMode="natt";
+	IpsecEsp="3des-md5-96";
+	IpsecIke="3des-sha-modp2048";
+	VtunProfile="";
 	saveUserPassword=false;
 	savePsk=false;
 	useAdvancedSettings=false;
@@ -77,6 +85,7 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	useGlobalIpsecSecret=false;
 	doPingIP=false;
 	useSpecialRemoteID=false;
+	useSpecialLocalID=false;
 	useUdp=true;
 	useUdpPort=false;
 	useDnsServer=false;
@@ -130,6 +139,7 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	useGlobalIpsecSecret=false;
 	doPingIP=false;
 	useSpecialRemoteID=false;
+	useSpecialLocalID=false;
 	useUdp=false;
 	useUdpPort=false;
 	useDnsServer=false;
@@ -184,6 +194,10 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 	allowEmptyPrivateKeyPassword=false;
 	useSmartcard=false;
 	allowIpAddressChangeOfPeer=false;
+	useSearchDomainInResolvConf=false;
+	disableDataEncryption=false;
+	useAuthenticationAlgorithm=false;
+	fixPathMtuDiscoveryProblem=false;
 
 	PeerTimeout=60;
 	ReconnectDelay=5;
@@ -206,6 +220,162 @@ VpnAccountData::VpnAccountData( ConnectionType ConnType,const QString& Name)
 VpnAccountData::~VpnAccountData()
 {}
 
+/*
+VpnAccountData::VpnAccountData(const VpnAccountData& data)
+{
+	Name = data.Name;
+	Gateway = data.Gateway;
+	ID = data.ID;
+	Username = data.Username;
+	UserPassword = data.UserPassword;
+	IkeGroup = data.IkeGroup;
+	PerfectForwardSecrecy = data.PerfectForwardSecrecy;
+	EncryptionAlgorithm = data.EncryptionAlgorithm;
+	AuthenticationAlgorithm = data.AuthenticationAlgorithm;
+	NtDomainName = data.NtDomainName;
+	ApplicationVersion = data.ApplicationVersion;
+	RemoteNetAddr = data.RemoteNetAddr;
+	RemoteNetMask = data.RemoteNetMask;
+	PreSharedKey = data.PreSharedKey;
+	x509Certificate = data.x509Certificate;
+	CaCertificate = data.CaCertificate;
+	NetworkDevice = data.NetworkDevice;
+	PrivateKeyPass = data.PrivateKeyPass;
+	PrivateKey = data.PrivateKey;
+	CertPath = data.CertPath;
+	AuthType = data.AuthType;
+	pingHostIP = data.pingHostIP;
+	SpecialRemoteID = data.SpecialRemoteID;
+	SpecialLocalID = data.SpecialLocalID;
+	LocalIDType = data.LocalIDType;
+	LocalVirtualIP = data.LocalVirtualIP;
+	RemoteVirtualIP = data.RemoteVirtualIP;
+	PreSharedKeyFile = data.PreSharedKeyFile;
+	HashAlgo = data.HashAlgo;
+	UseUserdefiniedCipher = data.UseUserdefiniedCipher;
+	DnsServer = data.DnsServer;
+	CommandBeforeConnect= data.CommandBeforeConnect;
+	CommandAfterConnect= data.CommandAfterConnect;
+	CommandBeforeDisconnect= data.CommandBeforeDisconnect;
+	CommandAfterDisconnect= data.CommandAfterDisconnect;
+	Description = data.Description;
+	SpecialServerCertificate= data.SpecialServerCertificate;
+	VirtualIP = data.VirtualIP;
+	TunnelDeviceType = data.TunnelDeviceType;
+	NsCertType = data.NsCertType;
+	UserdefiniedCipher = data.UserdefiniedCipher;
+	TlsAuthFile= data.TlsAuthFile;
+	HttpProxy= data.HttpProxy;
+	ExchangeMode = data.ExchangeMode;
+	TlsRemoteHost= data.TlsRemoteHost;
+	RightNextHop = data.RightNextHop;
+	LeftNextHop = data.LeftNextHop;
+	HttpProxyAuthType= data.HttpProxyAuthType;
+	HttpProxyUser= data.HttpProxyUser;
+	HttpProxyPass= data.HttpProxyPass;
+	Pkcs11Providers= data.Pkcs11Providers;
+	Pkcs11SlotType= data.Pkcs11SlotType;
+	Pkcs11Slot= data.Pkcs11Slot;
+	Pkcs11IdType= data.Pkcs11IdType;
+	Pkcs11Id= data.Pkcs11Id;
+	Pkcs11SignMode= data.Pkcs11SignMode;
+	AuthMethod = data.AuthMethod;
+	SearchDomainInResolvConf= data.SearchDomainInResolvConf;
+	AuthenticationDirection = data.AuthenticationDirection;
+	CiscoNatMode= data.CiscoNatMode;
+	IpsecEsp= data.IpsecEsp;
+	IpsecIke= data.IpsecIke;
+	AdditionalNetworkRoutes= data.QStringList AdditionalNetworkRoutes;
+	saveUserPassword = data.saveUserPassword;
+	savePsk = data.savePsk;
+	useAdvancedSettings = data.useAdvancedSettings;
+	useIkeGroup = data.useIkeGroup;
+	usePerfectForwardSecrety = data.usePerfectForwardSecrety;
+	useNtDomainName = data.useNtDomainName;
+	useApplicationVersion = data.useApplicationVersion;
+	useLocalPort = data.useLocalPort;
+	useRemotePort = data.useRemotePort;
+	useSingleDes = data.useSingleDes;
+	useGlobalIpsecSecret = data.useGlobalIpsecSecret;
+	doPingIP = data.doPingIP;
+	useSpecialRemoteID = data.useSpecialRemoteID;
+	useSpecialLocalID = data.useSpecialLocalID;
+	useUdp = data.useUdp;
+	useUdpPort = data.useUdpPort;
+	useDnsUpdate = data.useDnsUpdate;
+	useDnsServer = data.useDnsServer;
+	useGetDnsFromPeer = data.useGetDnsFromPeer;
+	refuse40BitEncryption = data.refuse40BitEncryption;
+	refuse128BitEncryption = data.refuse128BitEncryption;
+	allowStatefulMode= data.allowStatefulMode;
+	requireMppe = data.requireMppe;
+	refuseEap = data.refuseEap;
+	useNoIpDefault= data.useNoIpDefault;
+	disableMPPEComp= data.disableMPPEComp;
+	executeCmdBeforeConnect= data.executeCmdBeforeConnect;
+	executeCmdAfterConnect= data.executeCmdAfterConnect;
+	executeCmdBeforeDisconnect= data.executeCmdBeforeDisconnect;
+	executeCmdAfterDisconnect= data.executeCmdAfterDisconnect;
+	useNoBsdComp= data.useNoBsdComp;
+	useNoDeflate= data.useNoDeflate;
+	setDefaultRoute = data.setDefaultRoute;
+	replaceDefaultRoute = data.replaceDefaultRoute;
+	useMtu= data.useMtu;
+	useMru= data.useMru;
+	useVirtualIP = data.useVirtualIP;
+	PskIsInFile = data.PskIsInFile;
+	useAdditionalNetworkRoutes= data.useAdditionalNetworkRoutes;
+	useSpecialServerCertificate= data.useSpecialServerCertificate;
+	useUserdefinedPort= data.useUserdefinedPort;
+	keepDefaultRoute= data.keepDefaultRoute;
+	useNsCertType = data.useNsCertType;
+	useConnectionStatusCheck = data.useConnectionStatusCheck;
+	doReconnectAfterConnectionLost= data.doReconnectAfterConnectionLost;
+	disableLzoCompression= data.disableLzoCompression;
+	authWithUsernameAndPassword = data.authWithUsernameAndPassword;
+	allowEmptyGroupPassword = data.allowEmptyGroupPassword;
+	useUserdefiniedCipher= data.useUserdefiniedCipher;
+	useRedirectGateway= data.useRedirectGateway;
+	useTlsAuth = data.useTlsAuth;
+	useHttpProxy= data.useHttpProxy;
+	dontSaveUsername= data.dontSaveUsername;
+	useModeConfig= data.useModeConfig;
+	useReconnectDelay= data.useReconnectDelay;
+	useTlsRemoteHost= data.useTlsRemoteHost;
+	disableOpportunisticEncryption= data.disableOpportunisticEncryption;
+	useMssfix= data.useMssfix;
+	useFragment= data.useFragment;
+	disableCcp= data.disableCcp;
+	useSmartcard= data.useSmartcard;
+	useXauthInteractive= data.useXauthInteractive;
+	savePrivateKeyPassword= data.savePrivateKeyPassword;
+	useHttpProxyAuth= data.useHttpProxyAuth;
+	useOnlyCaCertAndUserAuth = data.useOnlyCaCertAndUserAuth;
+	useMailAddressAsIdentifier = data.useMailAddressAsIdentifier;
+	useRightNextHop= data.useRightNextHop;
+	useLeftNextHop= data.useLeftNextHop;
+	usePkcs11Providers= data.usePkcs11Providers;
+	allowEmptyPrivateKeyPassword= data.allowEmptyPrivateKeyPassword;
+	allowIpAddressChangeOfPeer= data.allowIpAddressChangeOfPeer;
+	useSearchDomainInResolvConf= data.useSearchDomainInResolvConf;
+	Mtu= data.Mtu;
+	Mru= data.Mru;
+	UdpPort = data.UdpPort;
+	LocalPort = data.LocalPort;
+	RemotePort = data.RemotePort;
+	UserdefinedPort= data.UserdefinedPort;
+	connectionStatusCheckSuccessCount = data.connectionStatusCheckSuccessCount;
+	connectionStatusInterval = data.connectionStatusInterval;
+	HttpProxyPort= data.HttpProxyPort;
+	HttpProxyTimeout= data.HttpProxyTimeout;
+	ReconnectDelay= data.ReconnectDelay;
+	Mssfix= data.Mssfix;
+	Fragment= data.Fragment;
+	PeerTimeout = data.PeerTimeout;
+	CommandAfterConnectDelayTime = data.CommandAfterConnectDelayTime;
+}
+*/
+
 QString VpnAccountData::getName() const
 {
 	return Name;
@@ -405,11 +575,26 @@ bool VpnAccountData::getUseSpecialRemoteID() const
 	return useSpecialRemoteID;
 }
 
+bool VpnAccountData::getUseSpecialLocalID() const
+{
+	return useSpecialLocalID;
+}
+
 QString VpnAccountData::getSpecialRemoteID() const
 {
 	return SpecialRemoteID;
 }
 
+QString VpnAccountData::getSpecialLocalID() const
+{
+	return SpecialLocalID;
+}
+
+QString VpnAccountData::getLocalIDType() const
+{
+	return LocalIDType;
+}
+
 bool VpnAccountData::getUseUdp() const
 {
 	return useUdp;
@@ -425,6 +610,11 @@ int VpnAccountData::getUdpPort() const
 	return UdpPort;
 }
 
+bool VpnAccountData::getUseDnsUpdate() const
+{
+	return useDnsUpdate;
+}
+
 bool VpnAccountData::getUseDnsServer() const
 {
 	return useDnsServer;
@@ -910,6 +1100,55 @@ int VpnAccountData::getCommandAfterConnectDelayTime() const
 	return CommandAfterConnectDelayTime;
 }
 
+bool VpnAccountData::getUseSearchDomainInResolvConf() const
+{
+	return useSearchDomainInResolvConf;
+}
+
+QString VpnAccountData::getSearchDomainInResolvConf() const
+{
+	return SearchDomainInResolvConf;
+}
+
+QString VpnAccountData::getAuthenticationDirection() const
+{
+	return AuthenticationDirection;
+}
+
+QString VpnAccountData::getCiscoNatMode() const
+{
+	return CiscoNatMode;
+}
+
+QString VpnAccountData::getIpsecEsp() const
+{
+	return IpsecEsp;
+}
+QString VpnAccountData::getIpsecIke() const
+{
+	return IpsecIke;
+}
+
+QString VpnAccountData::getVtunProfile() const
+{
+	return VtunProfile;
+}
+
+bool VpnAccountData::getDisableDataEncryption() const
+{
+	return disableDataEncryption;
+}
+
+bool VpnAccountData::getUseAuthenticationAlgorithm() const
+{
+	return useAuthenticationAlgorithm;
+}
+
+bool VpnAccountData::getFixPathMtuDiscoveryProblem() const
+{
+	return fixPathMtuDiscoveryProblem;
+}
+
 /* set methods */
 void VpnAccountData::setConnectionType( ConnectionType type )
 {
@@ -1101,11 +1340,26 @@ void VpnAccountData::setUseSpecialRemoteID(bool useSpecialRemoteID)
 	this->useSpecialRemoteID = useSpecialRemoteID;
 }
 
+void VpnAccountData::setUseSpecialLocalID(bool useSpecialLocalID)
+{
+	this->useSpecialLocalID = useSpecialLocalID;
+}
+
 void VpnAccountData::setSpecialRemoteID(const QString& SpecialRemoteID)
 {
 	this->SpecialRemoteID = SpecialRemoteID;
 }
 
+void VpnAccountData::setSpecialLocalID(const QString& SpecialLocalID)
+{
+	this->SpecialLocalID = SpecialLocalID;
+}
+
+void VpnAccountData::setLocalIDType(const QString& LocalIDType)
+{
+	this->LocalIDType = LocalIDType;
+}
+
 void VpnAccountData::setUseUdp(bool useUdp)
 {
 	this->useUdp = useUdp;
@@ -1121,6 +1375,11 @@ void VpnAccountData::setUdpPort(int UdpPort)
 	this->UdpPort = UdpPort;
 }
 
+void VpnAccountData::setUseDnsUpdate(bool useDnsUpdate )
+{
+	this->useDnsUpdate = useDnsUpdate;
+}
+
 void VpnAccountData::setUseDnsServer(bool useDnsServer )
 {
 	this->useDnsServer = useDnsServer;
@@ -1612,3 +1871,52 @@ void VpnAccountData::setCommandAfterConnectDelayTime( int CommandAfterConnectDel
 	this->CommandAfterConnectDelayTime = CommandAfterConnectDelayTime;
 }
 
+void VpnAccountData::setUseSearchDomainInResolvConf( bool useSearchDomainInResolvConf)
+{
+	this->useSearchDomainInResolvConf = useSearchDomainInResolvConf;
+}
+
+void VpnAccountData::setSearchDomainInResolvConf(QString SearchDomainInResolvConf)
+{
+	this->SearchDomainInResolvConf = SearchDomainInResolvConf;
+}
+
+void VpnAccountData::setAuthenticationDirection(QString AuthenticationDirection)
+{
+	this->AuthenticationDirection = AuthenticationDirection;
+}
+
+void VpnAccountData::setCiscoNatMode(QString CiscoNatMode)
+{
+	this->CiscoNatMode = CiscoNatMode;
+}
+
+void VpnAccountData::setIpsecEsp(QString IpsecEsp)
+{
+	this->IpsecEsp = IpsecEsp;
+}
+
+void VpnAccountData::setIpsecIke(QString IpsecIke)
+{
+	this->IpsecIke = IpsecIke;
+}
+
+void VpnAccountData::setVtunProfile(QString VtunProfile)
+{
+	this->VtunProfile = VtunProfile;
+}
+
+void VpnAccountData::setDisableDataEncryption(bool disableDataEncryption)
+{
+	this->disableDataEncryption = disableDataEncryption;
+}
+
+void VpnAccountData::setUseAuthenticationAlgorithm(bool useAuthenticationAlgorithm)
+{
+	this->useAuthenticationAlgorithm = useAuthenticationAlgorithm;
+}
+
+void VpnAccountData::setFixPathMtuDiscoveryProblem(bool fixPathMtuDiscoveryProblem)
+{
+	this->fixPathMtuDiscoveryProblem = fixPathMtuDiscoveryProblem;
+}
