@@ -31,9 +31,7 @@
 class VpnAccountData : public QObject
 {
 public:
-	enum ConnectionType {cisco=0, racoon=1, freeswan=2, pptp=3,openvpn=4,l2tpd_racoon=5,l2tpd_freeswan=6,other=7};
-// 	enum ConnectionType {cisco=0, racoon=1, freeswan=2, pptp=3,openvpn=4,l2tpd_racoon=5,other=6};
-// 	enum ConnectionType {cisco=0, racoon=1, freeswan=2, pptp=3,openvpn=4,other=5};
+	enum ConnectionType {cisco=0, racoon=1, freeswan=2, pptp=3,openvpn=4,l2tpd_racoon=5,l2tpd_freeswan=6,ciscoorig=7,vtun=8,other=99};
 	enum AuthenticationType {cert=0, psk=1};
 
 	/**
@@ -50,6 +48,11 @@ public:
 	*/
 	~VpnAccountData();
 
+	/*
+	Copy constructor
+	*/
+	VpnAccountData(const VpnAccountData&);
+
 	ConnectionType getConnectionType() const; //< returns Connection type
 	QString getName() const; //< returns Name
 	QString getGateway() const; //< returns Gateway
@@ -69,13 +72,15 @@ public:
 	QString getCaCertificate() const; //< returns x509 certificate (CA)
 	QString getNetworkDevice() const; //< returns NetworkDevice
 	QString getCertPath() const; //<returns CertPath
-	QString getSpecialRemoteID() const; //< retunr SpecialRemoteID;
+	QString getSpecialRemoteID() const; //< returns SpecialRemoteID;
+	QString getSpecialLocalID() const; //< returns SpecialLocalID;
+	QString getLocalIDType() const; //< return Local ID type for racoon
 	QString getPingHostIP() const; //< returns last part of IP (host) for ping test
 	QString getPrivateKeyPass() const; //< returns PrivateKeyPass
 	QString getPrivateKey() const; //< returns PrivateKey
 	QString getDnsServer() const;
-	QString getLocalVirtualIP() const;
-	QString getRemoteVirtualIP() const;
+	QString getLocalVirtualIP() const; //< returns LocalVirtualIP
+	QString getRemoteVirtualIP() const; //< returns RemoteVirtualIP (tun at openvpn,pptp) or Netmask for (tap at openvpn)
 	QString getPreSharedKeyFile() const;
 	QString getCommandBeforeConnect() const;
 	QString getCommandAfterConnect() const;
@@ -104,6 +109,12 @@ public:
 	QString getPkcs11Id() const;
 	QString getPkcs11SignMode() const;
 	QString getAuthMethod() const;
+	QString getSearchDomainInResolvConf() const;
+	QString getAuthenticationDirection() const;
+	QString getCiscoNatMode() const;
+	QString getIpsecEsp() const;
+	QString getIpsecIke() const;
+	QString getVtunProfile() const;
 
 	int getLocalPort() const; //< returns LocalPort
 	int getRemotePort() const; //< returns RemotePort
@@ -135,8 +146,10 @@ public:
 	bool getUseGlobalIpsecSecret() const; //< returns useGlobalIpsecSecret
 	bool getDoPingIP() const; //< returns doPingIP
 	bool getUseSpecialRemoteID() const; //< returns useSpecialRemoteID
+	bool getUseSpecialLocalID() const; //< returns useSpecialLocalID
 	bool getUseUdp() const; //< returns useUdp
 	bool getUseUdpPort() const; //< returns useUdpPort
+	bool getUseDnsUpdate() const;
 	bool getUseDnsServer() const;
 	bool getUseGetDnsFromPeer() const;
 	bool getRefuse40BitEncryption() const;
@@ -191,6 +204,10 @@ public:
 	bool getUsePkcs11Providers() const;
 	bool getAllowEmptyPrivateKeyPassword() const;
 	bool getAllowIpAddressChangeOfPeer() const;
+	bool getUseSearchDomainInResolvConf() const;
+	bool getDisableDataEncryption() const;
+	bool getUseAuthenticationAlgorithm() const;
+	bool getFixPathMtuDiscoveryProblem() const;
 
 
 
@@ -283,10 +300,14 @@ public:
 	void setPrivateKeyPass( const QString &PrivateKeyPass );
 	void setPrivateKey( const QString &PrivateKey );
 	void setUseSpecialRemoteID( bool useSpecialRemoteID );
+	void setUseSpecialLocalID( bool useSpecialLocalID );
 	void setSpecialRemoteID( const QString &SpecialRemoteID );
+	void setSpecialLocalID( const QString &SpecialLocalID );
+	void setLocalIDType( const QString &LocalIDType);
 	void setUseUdp( bool useUdp );
 	void setUseUdpPort( bool useUdpPort);
 	void setUdpPort( int UdpPort );
+	void setUseDnsUpdate(bool useDnsUpdate );
 	void setUseDnsServer(bool useDnsServer );
 	void setDnsServer(const QString &DnsServer );
 	void setUseGetDnsFromPeer(bool useGetDnsFromPeer );
@@ -385,6 +406,16 @@ public:
 	void setAllowIpAddressChangeOfPeer( bool allowIpAddressChangeOfPeer );
 	void setAuthMethod( QString AuthMethod );
 	void setCommandAfterConnectDelayTime( int CommandAfterConnectDelayTime );
+	void setUseSearchDomainInResolvConf( bool useSearchDomainInResolvConf );
+	void setSearchDomainInResolvConf(QString SearchDomainInResolvConf );
+	void setAuthenticationDirection(QString AuthenticationDirection );
+	void setCiscoNatMode(QString CiscoNatMode );
+	void setIpsecEsp(QString IpsecEsp);
+	void setIpsecIke(QString IpsecIke);
+	void setVtunProfile(QString VtunProfile);
+	void setDisableDataEncryption(bool disableDataEncryption);
+	void setUseAuthenticationAlgorithm(bool useAuthenticationAlgorithm);
+	void setFixPathMtuDiscoveryProblem( bool fixPathMtuDiscoveryProblem);
 
 protected:
 	QString Name; //< Name of the profile
@@ -410,6 +441,8 @@ protected:
 	QString AuthType; //< Authentication type (cert/psk)
 	QString pingHostIP; //< IP of the host which should be pinged
 	QString SpecialRemoteID; //< userdefined ID of remote gateway
+	QString SpecialLocalID; //< userdefined ID of remote gateway
+	QString LocalIDType; //< type of the local ID for racoon
 	QString LocalVirtualIP; //< Local virtual IP for tunnel (openvpn)
 	QString RemoteVirtualIP; //< Remote virtual IP for tunnel (openvpn)
 	QString PreSharedKeyFile; //< for openvpn
@@ -442,6 +475,12 @@ protected:
 	QString Pkcs11Id;
 	QString Pkcs11SignMode;
 	QString AuthMethod; //< authorization method for pptp (chap/pap)
+	QString SearchDomainInResolvConf;
+	QString AuthenticationDirection; //< openvpn key and tls-auth direction (none,0,1)
+	QString CiscoNatMode;
+	QString IpsecEsp;
+	QString IpsecIke;
+	QString VtunProfile;
 
 	QStringList AdditionalNetworkRoutes;
 
@@ -458,8 +497,10 @@ protected:
 	bool useGlobalIpsecSecret; //< True if global group password from /etc/vpnc.conf should be used
 	bool doPingIP; //< True if pingHostIP should be pinged after connection is established
 	bool useSpecialRemoteID; //< True if userdefined ID of remote gateway instead of certificate issuer should be used
+	bool useSpecialLocalID; //< True if userdefined ID of local instead of certificate client should be used
 	bool useUdp; //< True if NAT-T should be used
 	bool useUdpPort; //< True if userdefined UDP port should be used
+	bool useDnsUpdate; //< False if we don't update resolv.conf
 	bool useDnsServer; //< True if userdefined DNS server should be used
 	bool useGetDnsFromPeer; //< True if DNS servers should be retrieved from peer (pptp)bool
 	bool refuse40BitEncryption; //< True if 40 bit encryption is refused (pptp)
@@ -514,6 +555,10 @@ protected:
 	bool usePkcs11Providers;
 	bool allowEmptyPrivateKeyPassword;
 	bool allowIpAddressChangeOfPeer;
+	bool useSearchDomainInResolvConf;
+	bool disableDataEncryption;
+	bool useAuthenticationAlgorithm;
+	bool fixPathMtuDiscoveryProblem; //< see http://pptpclient.sourceforge.net/howto-diagnosis.phtml#connections_freeze
 	int Mtu;
 	int Mru;
 	int UdpPort; //< Port number of UDP port
